<?php

/**
 * 
 * 
 *
 * @category  Cart
 * @package   http://opensource.org/licenses/MIT    MIT License
 * @link      http://codeigniter.com
 * @since     Version 1.0.0
 */
defined('BASEPATH') or exit('No direct script access allowed');

/**
 * CodeIgniter Cart Class
 * 
 * Cart operations.
 *
 * @category  Cart
 * @package   http://opensource.org/licenses/MIT    MIT License
 * @link      http://codeigniter.com
 */
class Cart extends MY_Controller
{

    /**
    | -----------------------------------------------------
    | ---------
    |
    | MODULE:           CART CONTROLLER
    | -----------------------------------------------------
    | This is Cart module controller file.
    | -----------------------------------------------------
     **/
    function __construct()
    {
        parent::__construct();
        $this->load->model('cart_model');
    }

    /**
     * Check out page 
     * SHOWING CART ITEMS
     *
     * @return array
     **/
    function index()
    {

        if (empty($this->cart->contents())) {
            redirect(URL_MENU);
        }

        if ($this->input->post('submit_type') == 'save_order') {
           
            if (isset($this->config->item('site_settings')->time_zone)) {
                date_default_timezone_set($this->config->item('site_settings')->time_zone);
            }


            $current_time = date('H:i');
            $from_time = get_today_from_time();
            $to_time =  get_today_to_time();


            $closed_status = get_today_closed_status();
            if ($closed_status) {
                $this->prepare_flashmessage('Sorry, we are closed today. Please try again later.', 2);
                redirect(URL_MENU);
                exit;
            }

            if ($from_time != '' && $to_time != '' && isBetween($from_time, $to_time, $current_time) == true) {

                $addons_total = 0;
                foreach ($this->cart->contents() as $items) {

                    if (isset($items['options']['addons_cost_per_item'])) {
                        $addons_total = ($addons_total + $items['options']['addons_cost_per_item'])*$items['qty'];
                    }
                }
                
                $total_cost = (float) $this->cart->total() + $addons_total;
                $min_order = (float) $this->config->item('site_settings')->min_order;

                if (isset($min_order) && $min_order > 0) {

                    if ($total_cost < $min_order) {
                        $this->prepare_flashmessage('Minimum Order Amount is ' . $min_order . ' BD. Please Add more items to your cart.', 2);
                        redirect(URL_MENU);
                    } else {
                        $this->save_order();
                    }
                } else {
                    $this->save_order();
                }
            } else {

                $this->prepare_flashmessage('Sorry, we are closed at the moment. Try again later.', 2);
                redirect(URL_MENU);
            }
        }
        $addons_total = 0;
        foreach ($this->cart->contents() as $items) {

            if (isset($items['options']['addons_cost_per_item'])) {
                $addons_total =  ($addons_total + $items['options']['addons_cost_per_item']) * $items['qty'];
            }
        }
       

        $total_cost = (float) $this->cart->total() + $addons_total;
       
        $min_order = (float) $this->config->item('site_settings')->min_order;



        if (isset($min_order) && $min_order > 0) {
            if ($total_cost < $min_order) {
                $this->prepare_flashmessage('Minimum Order Amount is ' . $min_order . ' BD. Please Add more items to your cart.', 2);
                redirect(URL_MENU);
            }
        }
        $areas = $this->base_model->get_active_areas();
        $branches = $this->base_model->get_active_branches();
        $final_areas = array();
        foreach ($areas as $a) {
            if (!array_key_exists($a->govern, $final_areas)) {

                $final_areas[$a->govern] = array();
            }

            $temp_array = array();
            $temp_array['service_provide_location_id'] = $a->service_provide_location_id;
            $temp_array['locality'] = $a->locality;
            $temp_array['area_email'] = $a->area_email;
            $temp_array['status'] = $a->status;
            array_push($final_areas[$a->govern], $temp_array);
        }

        $online_status = check_tap_status();
        $this->data['areas'] = $final_areas;
        $this->data['branches'] = $branches;
        $this->data['online_payment'] = $online_status;

        $this->data['content'] = 'n_cart';
        $this->data['hide_mob_checkout'] = '1';

        $this->_render_page(getTemplate(), $this->data);
    }



    /**
     * Add/Update Cart Items
     *
     * @return boolean
     **/
    function add_cart_item()
    {
        $model_fun = 'validate_add_cart_item';

        $result = $this->cart_model->$model_fun();


        if ($result) {
            
            // Check if user has javascript enabled
            if ($this->input->post('ajax') != '1') {

                redirect(URL_CART_INDEX); // If javascript is not enabled, reload the page with new data

            } else if ($result > 0 && $result != 999 && $result != 9999 && $result != 8888 && $result != 7777) {

                echo count($this->cart->contents()); // If javascript is enabled, return true, so the cart gets updated //item added/updated

            } else if ($result <= 0 && $result != 999 && $result != 9999) {

                echo $result; //Item not added/updated

            } else if ($result == 999) {

                echo $result; //Item already exist

            } else if ($result == 9999) {

                echo $result; //no items in cart
            } else if ($result == 8888) {

                echo $result; //no items in cart
            } else if ($result == 7777) {

                echo $result; //no items in cart
            }
        }
    }


    /**
     * Update Cart Items
     *
     * @return boolean
     **/
    function update_cart_item()
    {

        $model_fun = 'update_cart_item';

        $result = $this->cart_model->$model_fun();


        if ($result) {

            // Check if user has javascript enabled
            if ($this->input->post('ajax') != '1') {

                redirect(URL_CART_INDEX); // If javascript is not enabled, reload the page with new data

            } else if ($result > 0 && $result != 999 && $result != 9999 && $result != 8888 && $result != 7777) {

                echo count($this->cart->contents()); // If javascript is enabled, return true, so the cart gets updated //item added/updated

            } else if ($result <= 0 && $result != 999 && $result != 9999) {

                echo $result; //Item not added/updated

            } else if ($result == 999) {

                echo $result; //Item already exist

            } else if ($result == 9999) {

                echo $result; //no items in cart
            } else if ($result == 8888) {

                echo $result; //no items in cart
            } else if ($result == 7777) {

                echo $result; //no items in cart
            }
        }
    }


    /**
     * Remove Cart Items
     *
     * @return boolean
     **/
    function remove_cart_item()
    {
        $item_row_id = $this->input->post('item_row_id'); //rowid

        if (empty($item_row_id)) {
            return FALSE;
        }

        if ($this->cart->remove($item_row_id)) {

            // Check if user has javascript enabled
            if ($this->input->post('ajax') != '1') {

                redirect(URL_CART_INDEX); // If javascript is not enabled, reload the page with new data

            } else {

                // echo count($this->cart->contents()); // If javascript is enabled, return true, so the cart gets updated

                //item removed from cart
                //check cart items empty or not
                $total_items = count($this->cart->contents());
                if ($total_items > 0) {
                    echo $total_items;
                } else {
                    echo 999; //cart items empty
                }
            }
        } else {
            return FALSE;
        }
    }

    /**
     * Empty Cart Items
     *
     * @return boolean
     **/
    function empty_cart()
    {
        $this->cart->destroy(); // Destroy all cart data
        redirect(URL_CART_INDEX); // Refresh te page
    }



    /**
     * Save Order
     *
     * @return boolean
     **/
    function save_order()
    {
        $areas = $this->base_model->get_active_areas();
        $final_areas = array();
        foreach ($areas as $a) {
            if (!array_key_exists($a->govern, $final_areas)) {

                $final_areas[$a->govern] = array();
            }

            $temp_array = array();
            $temp_array['service_provide_location_id'] = $a->service_provide_location_id;
            $temp_array['locality'] = $a->locality;
            $temp_array['area_email'] = $a->area_email;
            $temp_array['status'] = $a->status;
            array_push($final_areas[$a->govern], $temp_array);
        }
        $this->data['areas'] = $final_areas;
        $branches = $this->base_model->get_active_branches();
        $online_status = check_tap_status();
        $this->data['areas'] = $final_areas;
        $this->data['branches'] = $branches;
        $this->data['online_payment'] = $online_status;
        $this->data['hide_mob_checkout'] = '1';


        if (!$this->cart->contents()) {
            $this->prepare_flashmessage(get_languageword('please_add_items_to_your_cart'), 2);
            $this->data['content'] = 'n_cart';

            $this->_render_page(getTemplate(), $this->data);
        }


        if (!isset($_POST['order_type']) || $_POST['order_type'] == '' || ($_POST['order_type'] != 'delivery' && $_POST['order_type'] != 'takeaway' && $_POST['order_type'] != 'Digital Product')) {
            $this->prepare_flashmessage('Order Type is required', 2);
            $this->data['content'] = 'n_cart';

            $this->_render_page(getTemplate(), $this->data);
        }
        if (!($this->input->post('order_type'))) {
            $this->prepare_flashmessage('Order type is required', 2);
            $this->data['content'] = 'n_cart';

            $this->_render_page(getTemplate(), $this->data);
        }


        $this->form_validation->set_rules('order_type', 'Order Type', 'required|xss_clean');
        $this->form_validation->set_rules('full_name', get_languageword('full_name'), 'required|xss_clean');
        $this->form_validation->set_rules('mobile_number', get_languageword('phone'), 'required|xss_clean');
        $this->form_validation->set_rules('email_address', get_languageword('email_address'), 'required|valid_email|xss_clean');
        if ($_POST['order_type'] == 'delivery') {

            $this->form_validation->set_rules('flat_no', get_languageword('house'), 'required|xss_clean');
            $this->form_validation->set_rules('road', get_languageword('road'), 'required|xss_clean');
            $this->form_validation->set_rules('block', get_languageword('block'), 'required|xss_clean');
            $this->form_validation->set_rules('area', 'Area', 'required|is_natural_no_zero|xss_clean');
            $area_details = array();
            $area_details = $this->base_model->get_single_area((int) $this->input->post('area'));
            if (empty($area_details)) {
                $this->prepare_flashmessage('Invalid Area. Please try again.', 2);
                $this->data['content'] = 'n_cart';

                $this->_render_page(getTemplate(), $this->data);
            }
        } else if ($_POST['order_type'] == 'takeaway') {
            $this->form_validation->set_rules('branch', 'Branch', 'required|is_natural_no_zero|xss_clean');
            $branch_details = array();
            $branch_details = $this->base_model->get_single_branch((int) $this->input->post('branch'));
            if (empty($branch_details)) {
                $this->prepare_flashmessage('Invalid Branch. Please try again.', 2);
                $this->data['content'] = 'n_cart';

                $this->_render_page(getTemplate(), $this->data);
            }
        }

        if ($this->form_validation->run() == TRUE) {

            $total_cost = $this->cart->total();
            $input_data = array();
            $input_data['delivery_fee'] = 0;
            if ($_POST['order_type'] == 'delivery' && isset($this->config->item('site_settings')->delivery_fees) && (float) $this->config->item('site_settings')->delivery_fees > 0) {
                $input_data['delivery_fee'] = (float) $this->config->item('site_settings')->delivery_fees;
            }
            $total_cost += $input_data['delivery_fee']; //total items cost+delivery_fee - exclude addons_cost,points.
          
            $addons_total = 0;
            
            foreach ($this->cart->contents() as $items) {

                if (isset($items['options']['addons_cost_per_item'])) {
                    $addons_total+=  $items['options']['addons_cost_per_item']*$items['qty'];
                }
            }
          
            $total_cost += $addons_total;
       
            $input_data['customer_name']    = $this->input->post('full_name');
            $input_data['phone']            = $this->input->post('mobile_number');
            $input_data['email_address']    = $this->input->post('email_address');
            $input_data['status']           = "new";
            $input_data['order_type']       = $this->input->post('order_type');
            $input_data['payment_type']     = $this->input->post('payment_type');
            if ($_POST['order_type'] == 'takeaway') {
                $input_data['branch_id']         = $this->input->post('branch');
            } else {
                $input_data['house_no']         = $this->input->post('flat_no');
                $input_data['building']          = $this->input->post('building');
                $input_data['block']              = $this->input->post('block');
                $input_data['road']              = $this->input->post('road');
                $input_data['city_id']            = ($_POST['area'] && strlen($_POST['area'])>0)?$_POST['area']: null;
            }
            $input_data['message']          = $this->input->post('instructions');
            $input_data['order_date']       = date("Y-m-d");
            $input_data['order_time']       = date('H:i A');
            $input_data['total_cost']       = $total_cost;


            $input_data['no_of_items']      = count($this->cart->contents());

            $input_data['date_created']     = date('Y-m-d H:i:s');
            $input_data['date_updated']     = date('Y-m-d');

            $this->session->set_userdata('is_valid_request', 1);
            $this->session->set_userdata('order_data', $input_data);

            $this->order_success();
        } else {
            $m = "";
            foreach ($this->form_validation->get_all_errors() as $key => $value) {
                $m .= $value . "<br/>";
            }
            $this->prepare_flashmessage($m, 2);

            $this->data['content'] = 'n_cart';

            $this->_render_page(getTemplate(), $this->data);
        }
    }


    function get_order_id()
    {
        $success = 0;
        $order_id = 0;
        if ($this->session->userdata('order_data') && $this->session->userdata('is_valid_request')) {
            $input_data = $this->session->userdata('order_data');
            if ($input_data['payment_type'] == 'cash' || $input_data['payment_type'] == 'cashCard' || $input_data['payment_type'] == 'benefitPay') {
                $input_data['paid_date']            = NULL;
                $input_data['transaction_id']       = NULL;
                $input_data['payer_id']             = NULL;
                $input_data['payer_email']          = NULL;
                $input_data['payer_name']           = NULL;
                if($input_data['payment_type'] == 'cash') {
                    $input_data['payment_status']       = 'CASH ON DELIVERY';
                }
                if($input_data['payment_type'] == 'cashCard') {
                    $input_data['payment_status']  = 'Card on Delivery (Card Machine)';
                }
                if($input_data['payment_type'] == 'benefitPay') {
                    $input_data['payment_status']  = 'benefitPay';
                }

                

                $success = 1;
            } else if ($input_data['payment_type'] == 'online' && $this->input->post()) {
                $input_data['paid_date']         = NULL;
                $input_data['transaction_id']    = null;
                $input_data['paid_amount']       = null;
                $input_data['payer_id']          = null;
                $input_data['payer_email']       = null;
                $input_data['payer_name']        = $this->input->post('first_name') . " " . $this->input->post('last_name');
                $input_data['payment_status']   = 'UNKNOWN';

                $success = 1;
            }
            if ($success == 1) {
                $order_id = $this->base_model->insert_operation_id($input_data, TBL_ORDERS);
            }
        }
        return $order_id;
    }
    /**
     * Order Success
     *
     * @return boolean
     **/
    function order_success()
    {
        $success = 0;


        if ($this->session->userdata('order_data') && $this->session->userdata('is_valid_request')) {
            $input_data = $this->session->userdata('order_data');
            $order_id = $this->get_order_id();

            if ($order_id > 0) {

                $products_data     = array();
                $addons_data    = array();

                if ($this->cart->contents()) {
                    foreach ($this->cart->contents() as $items) {

                        $common_id = random_string('numeric', 3);

                        //Start 
                        $final_cost = "";
                        if (!empty($items['options']['item_option_price'])) {
                            $final_cost = (($items['options']['item_option_price']) * $items['qty']); //items_cost
                        } else if (!empty($items['options']['item_cost'])) {
                            $final_cost = (($items['options']['item_cost']) * $items['qty']); //items_cost
                        }
                        if (!empty($items['options']['addons_cost_per_item'])) {
                            $final_cost += $items['options']['addons_cost_per_item']; //items_cost+addons_cost
                        }
                        //End 
                        array_push(
                            $products_data,
                            array(
                                "is_deleted"        => 0,
                                "order_id"             => $order_id,
                                "item_id"             => $items['id'],
                                "menu_id"             => $items['options']['menu_id'],
                                "item_name"         => $items['name'],
                                "item_image_name"    => '',
                                "size_name"            =>  '',
                                "size_price"        => '',
                                "item_qty"            => $items['qty'],
                                "common_id"            => $common_id,
                                "item_cost"            => $items['price'],
                                "final_cost"        => $final_cost
                            )
                        );
                        
                        foreach ($items['options'] as $key => $v) {

                            if (is_array($v) and $key != 'addons') {
                                    array_push(
                                        $addons_data,
                                        array(
                                            "order_id"        => $order_id,
                                            "item_id"        => $items['id'],
                                            "addon_name"    => $v['item_option_name'],
                                            "price"            => $v['item_option_price'],
                                            "quantity"        => 1,
                                            "final_cost"    => $v['item_option_price'],
                                            "common_id"        => $common_id,
                                            "is_deleted"    => 0,
                                            "is_mandatory" => true

                                        )
                                    );
                            }
                        }
                        //Prepare Add-ons Data
                        if (!empty($items['options']['addons'])) {

                            foreach ($items['options']['addons'] as $key => $value) {
                                $vals = explode('=', $value);
                                array_push(
                                    $addons_data,
                                    array(
                                        "order_id"        => $order_id,
                                        "item_id"        => $items['id'],
                                        "addon_name"    => $vals[3],
                                        "price"            => $vals[1],
                                        "quantity"        => $vals[2],
                                        "final_cost"    => ($vals[1] * $vals[2]),
                                        "common_id"        => $common_id,
                                        "is_deleted"    => 0,
                                        "is_mandatory" => false
                                    )
                                );
                            }
                        }
                    }




                    if (!empty($products_data)) {
                        $this->db->insert_batch(TBL_PREFIX . TBL_ORDER_PRODUCTS, $products_data);
                    }


                    if (!empty($addons_data)) {
                        $this->db->insert_batch(TBL_PREFIX . TBL_ORDER_ADDONS, $addons_data);
                    }
                }



                //Email/SMS Alerts to User/Admin

                /////////////////////////////////////////////////////////////////////////////////////////////////////////////
                if ($input_data['payment_type'] == 'cash' || $input_data['payment_type'] == 'cashCard' || $input_data['payment_type'] == 'benefitPay') {
                    sendAdminEmail($order_id);
                    sendCustomerEmail($order_id);


                    $this->session->unset_userdata('is_valid_request');
                    $this->session->unset_userdata('order_data');
                    $this->cart->destroy(); // Destroy all cart data

					
                    $this->session->set_userdata('order_id', $order_id);
                    redirect(URL_SUCCESS);
                } else {
                    error_reporting(0);
                    $temp_key = get_tap_active_key();
                    if ($temp_key && strlen($temp_key) > 0) {
                        $api_key = explode('|||', $temp_key);
                        if (isset($api_key[0]) && isset($api_key[1])) {
                            $full_name = explode(' ', $input_data['customer_name']);

                            $headers = array(
                                "authorization: Bearer " . $api_key[0],
                                "cache-control: no-cache",
                                "content-type: application/json"
                            );
                            $charge = new stdClass();
                            $charge->amount = $input_data['total_cost'];
                            $charge->currency = $api_key[1];
                            $charge->threeDSecure = true;
                            $charge->save_card = false;
                            $charge->reference->transaction = $order_id;
                            $charge->reference->order = $order_id;
                            $charge->receipt->email = false;
                            $charge->receipt->sms = false;
                            $charge->customer->first_name = $full_name[0];
                            if (isset($full_name[1]) && isset($full_name[2])) {
                                $charge->customer->middle_name = $full_name[2];
                            } else if (isset($full_name[1])) {
                                $charge->customer->last_name = $full_name[1];
                            }
                            $charge->customer->email = $input_data['email_address'];
                            $charge->customer->phone->country_code = get_tap_country_code();
                            $charge->customer->phone->number = $input_data['phone'];
                            $charge->source->id = 'src_all';
                            $charge->redirect->url = URL_CART_POST;

                            $response = json_decode(create_curl_request(TAP_CHARGE_URL, json_encode($charge), $headers));

                            if ($response && $response->id && $response->status && $response->transaction->url) {
                                $charge_id = $response->id;
                                $data['transaction_id'] = $charge_id;
                                $data['payment_status'] = $response->status;
                                $where['order_id'] = $order_id;
                                $this->base_model->update_operation($data, TBL_ORDERS, $where);
                                header("Location: " . $response->transaction->url);
                            } else {
                                $this->prepare_flashmessage("There was a problem with our payment gateway please try another payment method. Contact us if problem persists.", 2);
                                redirect(URL_CART_INDEX);
                            }
                        } else {
                            $this->prepare_flashmessage("There was a problem with our payment gateway please try another payment method. Contact us if problem persists.", 2);
                            redirect(URL_CART_INDEX);
                        }
                    } else {
                        $this->prepare_flashmessage("There was a problem with our payment gateway please try another payment method. Contact us if problem persists.", 2);
                        redirect(URL_CART_INDEX);
                    }
                }
            } else {
                $this->prepare_flashmessage("We are having some techincal problems and were unable to process your order. Please contact us.", 2);
                redirect(URL_CART_INDEX);
            }
        } else {
            $this->prepare_flashmessage("Invalid Operation", 1);
            redirect(URL_CART_INDEX);
        }
    }

    function payment_status()
    {
        $error_m = "There was a problem accessing our payment gateway. Contact us if problem persists.";
        error_reporting(0);
        if (isset($_GET['tap_id'])) {

            $tap_id = $_GET['tap_id'];
            $order = $this->base_model->get_query_result("SELECT * FROM " . TBL_PREFIX . TBL_ORDERS . " WHERE `transaction_id`='" . $tap_id . "'");

            if (!empty($order)) {
                $order = $order[0];
                $order_id = $order->order_id;
                $temp_key = get_tap_active_key();
                $this->session->set_userdata('order_id', $order_id);
                if ($temp_key && strlen($temp_key) > 0) {
                    $api_key = explode('|||', $temp_key);
                    if (isset($api_key[0]) && isset($api_key[1])) {

                        $headers = array(
                            "authorization: Bearer " . $api_key[0],
                            "cache-control: no-cache",
                            "content-type: application/json"
                        );

                        $response = json_decode(create_curl_request(TAP_CHARGE_URL . "/" . $tap_id, '{}', $headers, "GET"));

                        if ($response) {
                            if (isset($response->status)) {
                                $data = $where = array();
                                $data['payment_status'] = $response->status;
                                $data['payer_name'] = $response->status;
                            }

                            $where['order_id'] = $order_id;
                            if ($order->payment_status != $response->status) {

                                $this->base_model->update_operation($data, TBL_ORDERS, $where);
                                if ($response->status == 'CAPTURED') {
                                    sendAdminEmail($order_id);
                                    sendCustomerEmail($order_id);
                                }
                            }
                            switch ($response->status) {
                                case 'CAPTURED':
                                    $this->session->unset_userdata('is_valid_request');
                                    $this->session->unset_userdata('order_data');
                                    $this->cart->destroy();
                                    redirect(URL_SUCCESS);
                                    break;
                                case 'INITIATED':
?>
                                    <p><a href="<?php echo $response->transaction->url; ?>" title="proceed to payment">Click here</a> to proceed to payment page to complete your order. <br /> Or <a href="<?php echo base_url(); ?>" title="Go to home">Click here</a> to go to homepage</p>
<?php
                                    break;


                                default:
                                    redirect(URL_FAILED . "/?status=" . $response->status);
                            }
                        } else {
                            $this->prepare_flashmessage($error_m, 2);
                            redirect(URL_CART_INDEX);
                        }
                    } else {
                        $this->prepare_flashmessage($error_m, 2);
                        redirect(URL_CART_INDEX);
                    }
                } else {
                    $this->prepare_flashmessage($error_m, 2);
                    redirect(URL_CART_INDEX);
                }
            } else {
                redirect(URL_CART_INDEX);
            }
        } else {
            redirect(URL_CART_INDEX);
        }
    }

    /**
     * Book Order Success
     *
     * @return boolean
     **/
    function success()
    {
        if ($this->session->userdata('order_id')) {

            $order_id = $this->session->userdata('order_id');
            $this->session->unset_userdata('order_id');


            $this->data['order_id']        = $order_id;
            $this->data['activemenu']     = "home";
            $this->data['content']      = "n_success";
            $this->_render_page(getTemplate(), $this->data);
        } else {
            redirect(URL_MENU);
        }
    }

    function failed()
    {
        if ($this->session->userdata('order_id')) {

            $order_id = $this->session->userdata('order_id');
            $this->session->unset_userdata('order_id');


            $this->data['order_id']        = $order_id;
            $this->data['activemenu']     = "home";
            $this->data['content']      = "n_failure";
            $this->_render_page(getTemplate(), $this->data);
        } else {
            redirect(URL_MENU);
        }
    }
}
