<?php

/**
 * 
 * 
 *
 * @category  Cartmodel
 * @package   http://opensource.org/licenses/MIT    MIT License
 * @link      http://codeigniter.com
 * @since     Version 1.0.0
 */
defined('BASEPATH') or exit('No direct script access allowed');

/**
 * CodeIgniter Cart Model
 * 
 * Cart Model operations.
 *
 * @category  Cartmodel
 * @package   http://opensource.org/licenses/MIT    MIT License
 * @link      http://codeigniter.com
 */
class Cart_model extends CI_Model
{

    /**
    | -----------------------------------------------------
    | -------
    |
    | MODULE:           Cart_Model
    | -----------------------------------------------------
    | This is Cart_Model file.
    | -----------------------------------------------------
     **/
    function __construct()
    {
        parent::__construct();
        // $this->load->database();
        $this->load->library(array('session'));
        $this->load->library(array('ion_auth', 'form_validation', 'cart'));
    }

    /**
     * Add/Update an item to the cart
     *
     * @return boolean
     **/

    function validate_add_cart_item()
    {
        
        $id   = $this->input->post('item_id'); //item_id

        $qty  = $this->input->post('quantity'); // quantity
        $flag = TRUE;
        $extra_costs_total = 0;

        $this->db->where('item_id', $id); // Select where id matches the posted id
        $query = $this->db->get($this->db->dbprefix('items'), 1); // Select the items where a match is found and limit the query by 1

        // Check if a row has matched our item id
        if ($query->num_rows() > 0) {

            // We have a match!
            foreach ($query->result() as $row) {

                $item_cost = $row->item_cost; //item_cost from cr_items table	


                $item_option_id = ($this->input->post('item_option_id')) ? $this->input->post('item_option_id') : array();

                $addon_ids      = $this->input->post('addon_ids');

                //Check if items already exists and if so, update item
                if (($this->cart->contents()) && $this->input->post('rowid') != '') {

                    $item_id1 = $this->input->post('rowid'); //rowid



                    foreach ($this->cart->contents() as $item) {

                        if ($item['id'] == $id) {

                            if ($item['rowid'] == $item_id1) {

                                

                                $dat = array(
                                    'rowid' => $item['rowid'],
                                    'qty'   => $qty //new quantity
                                );


                                //ITEM OPTION START
                                $dat['price'] = $item_cost;

                                if (!empty($item_option_id)) {

                                    $this->db->select('*');
                                    $this->db->from(TBL_ITEM_OPTIONS);
                                    $this->db->join(TBL_OPTIONS_SETS, TBL_ITEM_OPTIONS . '.option_id = ' . TBL_OPTIONS_SETS . '.option_sets_id');
                                    $this->db->where_in('item_option_id', $item_option_id);
                                    $option_details = $this->db->get()->result();


                                    foreach ($option_details as $opt) {
                                        if ((float)$opt->price > 0) {
                                            $dat['price'] += (float)$opt->price; //item_cost included selected option -
                                        }

                                        $dat['options'][$opt->option_sets_id]['item_option_name']     =   $opt->option_sets_name." :".$opt->option_label;
                                        $dat['options'][$opt->option_sets_id]['item_option_id']         = $opt->item_option_id; //cr_item_options table -item_option_id-primary_key
                                        $dat['options'][$opt->option_sets_id]['option_id']             = $opt->option_id; //cr_options table - option_id - primary_key
                                        $dat['options'][$opt->option_sets_id]['item_option_price']     = $opt->price;
                                    }
                                    //ITEM OPTION END
                                }
                                if (!$this->check_missing_options($id, $item_option_id)) {
                                    $dat['options']['missing_options']     = 1;
                                }
                                if (!$this->check_missing_addons($id, $addon_ids)) {
                                    $dat['options']['missing_addons']   = 1;
                                }
                                $dat['options']['addons'] = array();

                                //ADD ONS START
                                if (!empty($addon_ids)) {

                                    $addons_cost_per_item = 0;
                                    $this->db->select('*');
                                    $this->db->from(TBL_ITEM_OPTIONS);
                                    $this->db->join(TBL_OPTIONS_SETS, TBL_ITEM_OPTIONS . '.option_id = ' . TBL_OPTIONS_SETS . '.option_sets_id');
                                    $this->db->where_in('item_option_id', $addon_ids);
                                    $adds = $this->db->get()->result();

                                    foreach ($adds as $addon_det) {
                                        $addon_qty = $qty;
                                        $addons_cost_per_item += ($addon_det->price);

                                        $dat['options']['addons_cost_per_item'] = $addons_cost_per_item;

                                        array_push($dat['options']['addons'], $addon_det->item_option_id . "=" . $addon_det->price . "=" . $addon_qty . "=" .$addon_det->option_sets_name." :".$addon_det->option_label);
                                    }



                                    $extra_costs_total += ($addons_cost_per_item); //only addons cost

                                    $dat['options']['extra_costs_total'] = $extra_costs_total; //addons cost
                                }
                                //ADD ONS END

                                $dat['options']['description'] = $row->item_description;
                                $dat['options']['image']      = $row->item_image_name;
                                $dat['options']['item_cost'] = $item_cost;
                                $dat['options']['menu_id']   = $row->menu_id;
                                $dat['options']['is_offer']  = 0;
                              
                                $this->cart->update($dat);
                                
                                $flag = FALSE;
                                break;
                            }
                        }
                    }


                    if (!$flag) {
                        return TRUE;
                    } else {
                        return FALSE;
                    }
                }


                if ($flag) {

                    // Create an array with item information
                    $data = array(
                        'id'      => $id, //Item_id
                        'qty'     => $qty,
                        'price'   => $item_cost, //item_cost from cr_items table
                        'name'    => $row->item_name,
                        'options' => array('description' => $row->item_description, 'image' => $row->item_image_name, 'item_cost' => $item_cost, 'menu_id' => $row->menu_id, 'is_offer' => 0)
                    );




                    $option_details = array();
                    if (!empty($item_option_id)) {

                        $this->db->select('*');
                        $this->db->from(TBL_ITEM_OPTIONS);
                        $this->db->join(TBL_OPTIONS_SETS, TBL_ITEM_OPTIONS . '.option_id = ' . TBL_OPTIONS_SETS . '.option_sets_id');
                        $this->db->where_in('item_option_id', $item_option_id);
                        $option_details = $this->db->get()->result();
                    }

                    if (!empty($option_details)) {

                        foreach ($option_details as $opt) {
                            if ($opt->price > 0) {
                                $data['price'] += (float)$opt->price; //item_cost included selected option -
                            }

                            $data['options'][$opt->option_sets_id]['item_option_name']     =   $opt->option_sets_name." :".$opt->option_label;
                            $data['options'][$opt->option_sets_id]['item_option_id']         = $opt->item_option_id; //cr_item_options table -item_option_id-primary_key
                            $data['options'][$opt->option_sets_id]['option_id']             = $opt->option_id; //cr_options table - option_id - primary_key
                            $data['options'][$opt->option_sets_id]['item_option_price']     = $opt->price;
                        }
                    }

                    if (!$this->check_missing_options($id, $item_option_id)) {
                        $data['options']['missing_options']     = 1;
                    }
                    if (!$this->check_missing_addons($id, $addon_ids)) {
                        $data['options']['missing_addons']   = 1;
                    }

                    //ITEM OPTION END


                    //ADD ONS START
                    $data['options']['addons'] = array();

                    //ADD ONS START
                    if (!empty($addon_ids)) {

                        $addons_cost_per_item = 0;
                        $this->db->select('*');
                        $this->db->from(TBL_ITEM_OPTIONS);
                        $this->db->join(TBL_OPTIONS_SETS, TBL_ITEM_OPTIONS . '.option_id = ' . TBL_OPTIONS_SETS . '.option_sets_id');
                        $this->db->where_in('item_option_id', $addon_ids);
                        $adds = $this->db->get()->result();

                        foreach ($adds as $addon_det) {
                            $addon_qty = $qty;

                            $addons_cost_per_item += ($addon_det->price);

                            $data['options']['addons_cost_per_item'] = $addons_cost_per_item;

                            array_push($data['options']['addons'], $addon_det->item_option_id . "=" . $addon_det->price . "=" . $addon_qty . "=" . $addon_det->option_sets_name." :".$addon_det->option_label);
                        }



                        $extra_costs_total += ($addons_cost_per_item); //only addons cost

                        $data['options']['extra_costs_total'] = $extra_costs_total; //addons cost
                    }
                    //ADD ONS END
                  

                    // Add the data to the cart using the insert function that is available because we loaded the cart library
                    if ($this->cart->insert($data)) {

                        return count($this->cart->contents());
                    } else {
                        return FALSE;
                    }
                }
                /* else {
                return TRUE; // Finally return TRUE
                } */
            }
        } else {
            // Nothing found! Return FALSE! 
            return FALSE;
        }
    }
    function check_missing_addons($item_id = null, $addons_ids = array())
    {   
        $all_present = true;
        if ($item_id) {
            $complete_addons = array();
            $item_addons  =   $this->welcome_model->getItemAddons($item_id);
            foreach ($item_addons as $ia) {
                if (!array_key_exists($ia->option_sets_id, $complete_addons)) {
                    $complete_addons[$ia->option_sets_id] = array();
                    $complete_addons[$ia->option_sets_id]['ids'] = array();
                }
                $complete_addons[$ia->option_sets_id]['ids'][] =  $ia->item_option_id;
                $complete_addons[$ia->option_sets_id]['option_sets_min'] =  $ia->option_sets_min;
                $complete_addons[$ia->option_sets_id]['option_sets_max']=  $ia->option_sets_max;
            }
            
            if (!empty($complete_addons)) {
                
                foreach ($complete_addons as $k => $co) {
                
                   $intersection = array_intersect((array)$co['ids'], (array)$addons_ids);
                  
                    if (isset($co['option_sets_min']) && (int)$co['option_sets_min'] > 0) {
                    
                        if (count($intersection) < (int)$co['option_sets_min']) {
                            $all_present = false;
                        }
                        if (isset($co['option_sets_max']) && (int)$co['option_sets_max'] > 0) {
                            if ((int)count($intersection) > (int)$co['option_sets_max']) {
                                $all_present = false;
                            }
                        }
                    }
                }
            }
            return $all_present;
        }
    }
    function check_missing_options($item_id = null, $item_option_id = array())
    {
        $all_present = true;
        if ($item_id) {
            $item_options = $this->welcome_model->getItemOptions($item_id);
            $complete_options = array();
            foreach ($item_options as $io) {
                if (!array_key_exists($io->option_sets_id, $complete_options)) {
                    $complete_options[$io->option_sets_id] = array();
                }
                array_push($complete_options[$io->option_sets_id], $io->item_option_id);
            }
        
           
            if (!empty($complete_options)) {
                if (count(array($item_option_id)) != count(array($complete_options))) {
                    $all_present = false;       
                              
                } else {
                    foreach ($complete_options as $k => $co) {
                        if (empty(array_intersect($co, $item_option_id))) {
                            $all_present = false;
                        }
                    }
                }
            }
            return $all_present;
        }
    }
    /**
     * Update an item to the cart
     *
     * @return boolean
     **/
    function update_cart_item()
    {

        $rowid = $this->input->post('rowid');
        $type  = $this->input->post('type');

        $extra_costs_total = 0;

        $is_updated = 0;

        if ($rowid != '' && $type != '') {


            if (!empty($this->cart->contents())) {

                foreach ($this->cart->contents() as $item) {

                    if ($rowid == $item['rowid']) {

                        $qty = $item['qty'];


                        if ($type == 'decr') {

                            // echo 'QUANLSDFKF '.$qty;die();
                            if ($qty == 1) { //remove item from cart

                                $this->cart->remove($rowid);
                                $is_updated = 1;
                                break;
                            } else {


                                $dat = array('rowid' => $item['rowid'], 'id' => $item['id'], 'qty' => $qty - 1, 'price' => $item['price'], 'name' => $item['name']);
                                

                                $dat['options'] = $item['options'];
                          
                                $this->cart->update($dat);
                                $is_updated = 1;
                                break;
                            }
                        } else {

                            //item

                            $dat = array('rowid' => $item['rowid'], 'id' => $item['id'], 'qty' => $qty + 1, 'price' => $item['price'], 'name' => $item['name']);
                            $dat['options'] = $item['options'];

                           
                            //ADD ONS END


                            $this->cart->update($dat);
                            $is_updated = 1;
                            break;
                        }
                    }
                }



                if ($is_updated > 0) {

                    // return true;
                    $total_itms = count($this->cart->contents());
                    if ($total_itms <= 0) {
                        return 9999; //no items cart
                    } else {
                        return $total_itms;
                    }
                } else {
                    return FALSE;
                }
            } else {
                return FALSE;
            }
        } else {
            return FALSE;
        }
    }
}
