<?php

/**
 *
 * @category  Items
 * 
 * @since     Version 1.0.0
 */
defined('BASEPATH') or exit('No direct script access allowed');

/**
 * CodeIgniter Items Class
 * 
 * Items CRUD operations.
 *
 * @category  Items
 * 
 */
class Items extends MY_Controller
{

    /**
    | -----------------------------------------------------
    |
    | MODULE:           ITEMS CONTROLLER
    | -----------------------------------------------------
    | This is Items module controller file.
    | -----------------------------------------------------
     **/
    function __construct()
    {
        parent::__construct();
        $this->load->model('items_model');
        check_access('admin');
    }

    /**
     * Fetch Items
     *
     * @return array
     **/
    function index()
    {

        if ($this->input->post()) {
            /***
             * 
             * Delete Operation - Start 
             ***/
            $param1 = $this->input->post('param1');
            $param2 = $this->input->post('param2');

            if (in_array($param1, array('delete', 'delete_selected', 'activate_selected', 'deactivate_selected')) && !empty($param2)) {

                $msg = '';
                $status = 0;
                if ($param1 == "delete") {
                    $record = $this->base_model->fetch_records_from(TBL_ITEMS, array('item_id' => $param2));

                    if ($this->base_model->delete_record_new(TBL_ITEMS, array('item_id' => $param2))) {
                        //delete item addons
                        //delete item options
                        $this->base_model->delete_record_new(TBL_ITEM_OPTIONS, array('item_id' => $param2));


                        if (!empty($record)) {
                            $record = $record[0];
                            if ($record->item_image_name != '' && file_exists(ITEM_IMG_UPLOAD_PATH_URL . $record->item_image_name)) {
                                unlink(ITEM_IMG_UPLOAD_PATH_URL . $record->item_image_name);
                                unlink(ITEM_IMG_UPLOAD_THUMB_PATH_URL . $record->item_image_name);
                            }
                        }

                        $msg .= get_languageword('record_deleted_successfully');
                        $status = 0;
                    } else {
                        $msg .= get_languageword('record_not_deleted');
                        $status = 1;
                    }
                } else if ($param1 == "delete_selected") {
                    $rows_to_be_deleted = explode(',', $param2);

                    foreach ($rows_to_be_deleted as $row) :
                        $record = $this->base_model->fetch_records_from(TBL_ITEMS, array('item_id' => $row));
                        if (!empty($record)) {
                            $record = $record[0];
                            if ($record->item_image_name != '' && file_exists(ITEM_IMG_UPLOAD_PATH_URL . $record->item_image_name)) {
                                unlink(ITEM_IMG_UPLOAD_PATH_URL . $record->item_image_name);
                                unlink(ITEM_IMG_UPLOAD_THUMB_PATH_URL . $record->item_image_name);
                            }
                        }
                    endforeach;

                    if ($this->base_model->delete_record(TBL_ITEMS, 'item_id', $rows_to_be_deleted)) {
                        //delete item addons
                        //delete item options
                        $this->base_model->delete_record(TBL_ITEM_OPTIONS, 'item_id', $rows_to_be_deleted);

                        $msg .= get_languageword('selected_records_deleted_successfully');
                        $status = 0;
                    } else {
                        $msg .= get_languageword('record_not_deleted');
                        $status = 1;
                    }
                } else if ($param1 == "activate_selected") {
                    $rows_to_be_activated = explode(',', $param2);
                    if ($this->base_model->changestatus_multiple_recs(TBL_ITEMS, array('status' => 'Active'), 'item_id', $rows_to_be_activated)) {
                        $msg .= get_languageword('selected_records_activated_successfully');
                        $status = 0;
                    } else {
                        $msg .= get_languageword('record_not_activated');
                    }
                } else if ($param1 == "deactivate_selected") {
                    $rows_to_be_deactivated = explode(',', $param2);
                    if ($this->base_model->changestatus_multiple_recs(TBL_ITEMS, array('status' => 'Inactive'), 'item_id', $rows_to_be_deactivated)) {
                        $msg .= get_languageword('selected_records_deactivated_successfully');
                        $status = 0;
                    } else {
                        $msg .= get_languageword('record_not_deactivated');
                        $status = 1;
                    }
                }
                $this->prepare_flashmessage($msg, $status);
                redirect(URL_ITEMS_INDEX);
            }
        }

        $this->data['ajaxrequest'] = array(
            'url' => URL_ITEMS_AJAX_GET_LIST,
            'disablesorting' => '0,7',
            'order' => 6,
            'dir' => 'asc'
        );

        $this->data['css_js_files'] = array('data_tables');
        $this->data['activemenu']     = "items";
        $this->data['message']         = $this->session->flashdata('message');
        $this->data['pagetitle']     = get_languageword('view_items');
        $this->data['content']         = PAGE_ITEMS;
        $this->_render_page(TEMPLATE_ADMIN, $this->data);
    }

    /**
     * Fetch Items
     *
     * @return array
     **/
    function ajax_get_list()
    {
        if ($this->input->is_ajax_request()) {
            $data = array();
            $no = $_POST['start'];

            $records = $this->items_model->get_datatables();

            if (!empty($records)) {

                foreach ($records as $record) {
                    $no++;
                    $row = array();

                    $image = IMG_DEFAULT;
                    if ($record->item_image_name != '' && file_exists(ITEM_IMG_UPLOAD_PATH_URL . $record->item_image_name)) {
                        $image = ITEM_IMG_PATH . $record->item_image_name;
                    }

                    $row[] = '<input type="checkbox" name="check_rows[]" class="check_rows" value="' . $record->item_id . '"> ';

                    $row[] = '<span>' . $record->menu_name . '</span>';
                    $row[] = '<span>' . $record->item_name . '</span>';

                    $row[] = '<span>' . returnPrice($record->item_cost) . '</span>';

                    $row[] = '<span><img src="' . $image . '" class="img-responsive center-block"/></span>';

                    $checked = '';
                    $class = 'badge danger';
                    if ($record->status == 'Active') {
                        $checked = ' checked';
                        $class = 'badge success';
                    }
                    $row[] = '<span class="' . $class . '">' . $record->status . '</span>';
                    $row[] = $record->sort_order;

                    $dta = '';
                    $dta .= '<span>';
                    $dta .= form_open(URL_EDIT_ITEM);
                    $dta .= '<input type="hidden" name="item_id" value="' . $record->item_id . '">';
                    $dta .= '<button type="submit" name="edit_item" class="' . CLASS_EDIT_BTN . '"><i class="' . CLASS_ICON_EDIT . '" ></i></button>';
                    $dta .= form_close();
                    $dta .= '</span>';

                    $str = $dta;

                    $str .= '<a data-toggle="modal" data-target="#commonModal" title="' . get_languageword('delete') . '" class="' . CLASS_DELETE_BTN . '" onclick="set_fields(\'delete\', \'' . $record->item_id . '\');"><i class="' . CLASS_ICON_DELETE . '" ></i> </a>';

                    $row[] = $str;

                    $data[] = $row;
                }
            }

            $output = array(
                "draw" => $_POST['draw'],
                "recordsTotal" => $this->items_model->count_all(),
                "recordsFiltered" => $this->items_model->count_filtered(),
                "data" => $data
            );

            echo json_encode($output);
        }
    }

    /**
     * Add/Update Item
     *
     * @return boolean
     **/
    function add_item()
    {
        if (isset($_POST['addedit_item'])) {


            $msg = '';
            $status = 0;

            $this->form_validation->set_rules('item_name', get_languageword('item_name'), 'required|xss_clean');
            $this->form_validation->set_rules('item_cost', get_languageword('item_cost'), 'required|xss_clean');
            $this->form_validation->set_rules('sort_order', 'Sort order', 'required|is_natural|xss_clean');

            $this->form_validation->set_error_delimiters('<div class="error">', '</div>');

            $item_id = $this->input->post('item_id');

            if ($this->form_validation->run() == TRUE) {
                $data = array();
                $data['menu_id']    = $this->input->post('menu_id');
                $data['item_name']     = $this->input->post('item_name');
                $data['sort_order']     = $this->input->post('sort_order');
                $data['item_cost']     = $this->input->post('item_cost');
                $data['item_description'] = $this->input->post('item_description');
                $data['status']        = $this->input->post('status');


                if ($this->input->post('item_id') > 0) {
                    $where['item_id'] = $this->input->post('item_id');
                    if ($this->base_model->update_operation($data, TBL_ITEMS, $where)) {
                        $msg .= get_languageword('details_saved_successfully');
                        $status = 0;
                    } else {
                        $msg .= get_languageword('details_not_saved');
                        $status = 1;
                    }
                } else {
                    $unique_name = false;
                    $temp_pid = $this->randomString(16);
                    while ($unique_name == false) {
                        $p = $this->base_model->fetch_records_from(TBL_ITEMS, array('product_id' => $temp_pid));
                        if (empty($p)) {
                            $unique_name = true;
                        } else {
                            $temp_pid = $this->randomString(16);
                        }
                    }
                    $data['product_id'] = $temp_pid;

                    $item_id = $this->base_model->insert_operation_id($data, TBL_ITEMS);
                    if ($item_id) {
                        $msg .= get_languageword('details_saved_successfully');
                        $status = 0;
                    } else {
                        $msg .= get_languageword('details_not_saved');
                        $status = 1;
                    }
                }
                unset($data, $where);


                //Upload ITEM IMAGE
                if ($item_id > 0 && count($_FILES) > 0) {
                    if ($_FILES['item_image']['name'] != '' && $_FILES['item_image']['error'] != 4) {
                        if ($this->input->post('item_id') > 0) {
                            $record = $this->base_model->fetch_records_from(TBL_ITEMS, array('item_id' => $item_id));

                            if (!empty($record)) {
                                $record = $record[0];
                                if ($record->item_image_name != '' && file_exists(ITEM_IMG_UPLOAD_PATH_URL . $record->item_image_name)) {
                                    unlink(ITEM_IMG_UPLOAD_PATH_URL . $record->item_image_name);
                                    unlink(ITEM_IMG_UPLOAD_THUMB_PATH_URL . $record->item_image_name);
                                }
                            }
                        }


                        $ext = pathinfo($_FILES['item_image']['name'], PATHINFO_EXTENSION);
                        $file_name = 'item_' . uniqid() . random_new_string(3) . $item_id . '.' . $ext;
                        $config['upload_path']         = ITEM_IMG_UPLOAD_PATH_URL;
                        $config['allowed_types']     = ALLOWED_TYPES;

                        $config['file_name']  = $file_name;
                        $this->load->library('upload', $config);
                        $this->upload->initialize($config);

                        if ($this->upload->do_upload('item_image')) {
                            $data = array();
                            $data['item_image_name'] = $file_name;


                            $this->create_thumbnail($config['upload_path'] . $file_name, ITEM_IMG_UPLOAD_THUMB_PATH_URL . $file_name, THUMB_IMG_WIDTH, THUMB_IMG_HEIGHT);


                            $this->base_model->update_operation($data, TBL_ITEMS, array('item_id' => $item_id));
                        } else {
                            $msg .= '<br>' . strip_tags($this->upload->display_errors());
                            $status = 1;
                        }
                    }
                }

                if ($msg != '') {
                    $this->prepare_flashmessage($msg, $status);
                }
                if ($item_id) {
                    echo $this->show_item_form($item_id);
                    die();
                } else {
                    redirect(URL_ITEMS_INDEX, REFRESH);
                }
            }
        }

        //menus
        $menu_options = $this->base_model->get_menus_options('Active');

        // addons
        $addon_options = $this->base_model->get_addons_options('Active');

        $pagetitle = get_languageword('add_item');


        $this->data['menu_options']  = $menu_options;
        $this->data['addon_options'] = $addon_options;


        $this->data['css_js_files']  = array('form_validation');
        $this->data['pagetitle']     = $pagetitle;
        $this->data['activemenu']      = "items";
        $this->data['content']          = PAGE_ADDEDIT_ITEM;
        $this->_render_page(TEMPLATE_ADMIN, $this->data);
    }

    /**
     * Edit Item
     *
     * @return boolean
     **/
    function edit_item()
    {
        $this->load->model('items_model');

        if (isset($_POST['edit_item_save'])) {


            $msg = '';
            $status = 0;

            $this->form_validation->set_rules('item_name', get_languageword('item_name'), 'required|xss_clean');
            $this->form_validation->set_rules('item_cost', get_languageword('item_cost'), 'required|xss_clean');
            $this->form_validation->set_rules('sort_order', 'Sort order', 'required|is_natural|xss_clean');

            $this->form_validation->set_error_delimiters('<div class="error">', '</div>');

            $item_id = $this->input->post('item_id');

            if ($this->form_validation->run() == TRUE) {
                $data = array();
                $data['menu_id']    = $this->input->post('menu_id');
                $data['item_name']     = $this->input->post('item_name');
                $data['sort_order']     = $this->input->post('sort_order');
                $data['item_cost']     = $this->input->post('item_cost');
                $data['item_description'] = $this->input->post('item_description');
                $data['status']        = $this->input->post('status');

                $where['item_id'] = $this->input->post('item_id');
                if ($this->base_model->update_operation($data, TBL_ITEMS, $where)) {
                    $msg .= get_languageword('details_saved_successfully');
                    $status = 0;
                } else {
                    $msg .= get_languageword('details_not_saved');
                    $status = 1;
                }

                unset($data, $where);


                //Upload ITEM IMAGE
                if ($item_id > 0 && count($_FILES) > 0) {
                    if ($_FILES['item_image']['name'] != '' && $_FILES['item_image']['error'] != 4) {
                        if ($this->input->post('item_id') > 0) {
                            $record = $this->base_model->fetch_records_from(TBL_ITEMS, array('item_id' => $item_id));

                            if (!empty($record)) {
                                $record = $record[0];
                                if ($record->item_image_name != '' && file_exists(ITEM_IMG_UPLOAD_PATH_URL . $record->item_image_name)) {
                                    unlink(ITEM_IMG_UPLOAD_PATH_URL . $record->item_image_name);
                                    unlink(ITEM_IMG_UPLOAD_THUMB_PATH_URL . $record->item_image_name);
                                }
                            }
                        }

                        $ext = pathinfo($_FILES['item_image']['name'], PATHINFO_EXTENSION);
                        $file_name = 'item_' . uniqid() . random_new_string(3) . $item_id . '.' . $ext;

                        $config['upload_path']         = ITEM_IMG_UPLOAD_PATH_URL;
                        $config['allowed_types']     = ALLOWED_TYPES;

                        $config['file_name']  = $file_name;
                        $this->load->library('upload', $config);
                        $this->upload->initialize($config);

                        if ($this->upload->do_upload('item_image')) {
                            $data = array();
                            $data['item_image_name'] = $file_name;

                            $this->create_thumbnail($config['upload_path'] . $file_name, ITEM_IMG_UPLOAD_THUMB_PATH_URL . $file_name, THUMB_IMG_WIDTH, THUMB_IMG_HEIGHT);

                            $this->base_model->update_operation($data, TBL_ITEMS, array('item_id' => $item_id));
                        } else {
                            $msg .= '<br>' . strip_tags($this->upload->display_errors());
                            $status = 1;
                        }
                    }
                }

                if ($msg != '') {
                    $this->prepare_flashmessage($msg, $status);
                }

                echo $this->show_item_form($item_id);
                die();
            }
        } else if (isset($_POST['item_options_save'])) {
            $msg = '';
            $status = 0;
            $option_sets = $_POST['option_sets'];
            $sets = array();
            $item_id = $this->input->post('item_id');
            $this->form_validation->set_rules('item_id', 'Item ID', 'xss_clean|required|greater_than[0]');
            if(!empty($option_sets)) {
                foreach ($option_sets as $key => $val) {

                    $this->form_validation->set_rules("label[$key]", 'Label', 'xss_clean|required|trim');
                    $this->form_validation->set_rules("price[$key]", 'Price', 'xss_clean|required|trim|numeric');
                    array_push($sets, $key);
                }
            }
            $this->form_validation->set_error_delimiters('<div class="error">', '</div>');


            if ($this->form_validation->run() == TRUE) {

                $update_data = array();
                $insert_data = array();
                $update_ids = array();
                if(!empty($option_sets)) {
                foreach ($option_sets as $key => $arr) {
                    $index = 0;
                    foreach ($arr as $field) {
                        $temp_array = array();
                        $temp_option_id = $_POST['option_id'][$key][$index];
                        if ($temp_option_id == 'new') {
                            $temp_array = array(
                                'item_id' => $item_id,
                                'option_id' => $key,
                                'price' => $_POST['price'][$key][$index],
                                'option_label' => $_POST['label'][$key][$index]
                            );
                            array_push($insert_data, $temp_array);
                        } else {
                            $temp_array = array(
                                'item_id' => $item_id,
                                'option_id' => $key,
                                'item_option_id' => $temp_option_id,
                                'price' => $_POST['price'][$key][$index],
                                'option_label' => $_POST['label'][$key][$index]
                            );
                            array_push($update_data, $temp_array);
                            array_push($update_ids, $temp_option_id);
                        }
                        $index += 1;
                    }
                }
            }

                if ($this->items_model->addOptions($insert_data, $update_data, $update_ids, $item_id)) {
                    $msg .= get_languageword('updated_successfully');
                    $status = 0;
                } else {
                    $msg .= get_languageword('not_updated');
                    $status = 1;
                }

                if ($msg != '') {
                    $this->prepare_flashmessage($msg, $status);
                }
                echo $this->show_item_form($item_id,1);
                die();
            } else {
                $this->prepare_flashmessage(validation_errors(), 1);
                echo $this->show_item_form($item_id,1);
                die();
            }
        } else if (isset($_POST['edit_item'])) {

            $pagetitle = get_languageword('edit_item');
            $item_id = $this->input->post('item_id');


            if ($item_id > 0) {
                
                $record = $this->base_model->fetch_records_from(TBL_ITEMS, array('item_id' => $item_id));

                if (empty($record)) {
                    $this->prepare_flashmessage(get_languageword('no_details_found'), 2);
                    redirect(URL_ITEMS_INDEX);
                }
                $this->data['record'] =  $record[0];
                $selected = $this->items_model->get_item_options($item_id);
                $menu_options = $this->base_model->get_menus_options('Active');
                $final_selected = array();
                foreach ($selected as $item_option) {
                    $key = $item_option->option_sets_id;
                    if (!array_key_exists($key, $final_selected)) {

                        $final_selected[$key] = array();
                    }
                    array_push($final_selected[$key], $item_option);
                }
                if(isset($_POST['options_tab_active'])) {
                 $this->data['options_tab_active'] = 'yes';   
                }
                $this->data['options'] = $this->items_model->get_all_options();
                $this->data['menu_options']  = $menu_options;
                $this->data['item_selected_options'] = $final_selected;
            } else {
                redirect(URL_ITEMS_INDEX);
            }
        } else {
            redirect(URL_ITEMS_INDEX);
        }

        $this->data['css_js_files']  = array('form_validation');
        $this->data['pagetitle']     = $pagetitle;
        $this->data['activemenu']      = "items";
        $this->data['activesubmenu'] = 'addedit_addon';
        $this->data['content']          = PAGE_EDIT_ITEM;
        $this->_render_page(TEMPLATE_ADMIN, $this->data);
    }
    function show_item_form($item_id = null,$options =null)
    {
        $dta = '';

        if ($item_id) {
            $dta .= form_open(URL_EDIT_ITEM, array('id' => 'myForm'));
            $dta .= '<input type="hidden" name="item_id" value="' . $item_id . '">';
            $dta .= '<input type="hidden" name="edit_item" value="1"/>';
           if($options) {
            $dta .= '<input type="hidden" name="options_tab_active" value="1."/>';
           }
          
            $dta .= '<input type="submit" value="Click here if you are not redirected."/>';
            $dta .= form_close();
            $dta .= '<script type="text/javascript">
            document.getElementById("myForm").submit();
        </script>';
        }

        return $dta;
    }
}
