<?php

/**
 *
 * @category  Locations
 * 
 * @since     Version 1.0.0
 */
defined('BASEPATH') or exit('No direct script access allowed');
/**
 * CodeIgniter Locations Class
 * 
 * Locations CRUD operations.
 *
 * @category  Locations
 * 
 */
class Locations extends MY_Controller
{

    /**
    | -----------------------------------------------------
    |
    | MODULE:           LOCATIONS CONTROLLER
    | -----------------------------------------------------
    | This is Locations module controller file.
    | -----------------------------------------------------
     **/
    function __construct()
    {
        parent::__construct();
        check_access('admin');
    }

    /**
     * Fetch locations
     *
     * @return array
     **/
    function index()
    {
        redirect(URL_DELIVERY_LOCATIONS);
    }


    /**
     * Fetch delivery locations
     *
     * @return array
     **/
    function delivery_locations()
    {
        if ($this->input->post()) {
            /***
             * 
             * Delete Operation - Start 
             ***/
            $param1 = $this->input->post('param1');
            $param2 = $this->input->post('param2');

            if (in_array($param1, array('activate_selected', 'deactivate_selected')) && !empty($param2)) {

                $msg = '';
                $status = 0;
                if ($param1 == "activate_selected") {
                    $rows_to_be_activated = explode(',', $param2);
                    if ($this->base_model->changestatus_multiple_recs(TBL_SERVICE_PROVIDE_LOCATIONS, array('status' => 'Active'), 'service_provide_location_id', $rows_to_be_activated)) {
                        $msg .= get_languageword('selected_records_activated_successfully');
                        $status = 0;
                    } else {
                        $msg .= get_languageword('record_not_activated');
                    }
                } else if ($param1 == "deactivate_selected") {
                    $rows_to_be_deactivated = explode(',', $param2);
                    if ($this->base_model->changestatus_multiple_recs(TBL_SERVICE_PROVIDE_LOCATIONS, array('status' => 'Inactive'), 'service_provide_location_id', $rows_to_be_deactivated)) {
                        $msg .= get_languageword('selected_records_deactivated_successfully');
                        $status = 0;
                    } else {
                        $msg .= get_languageword('record_not_deactivated');
                        $status = 1;
                    }
                }
                $this->prepare_flashmessage($msg, $status);
                redirect(URL_DELIVERY_LOCATIONS);
            }
        }

        $areas = $this->base_model->get_all_areas();
        $branches = $this->base_model->get_all_branches();
        $final_areas = array();
        foreach ($areas as $a) {
            if (!array_key_exists($a->govern, $final_areas)) {

                $final_areas[$a->govern] = array();
            }

            $temp_array = array();
            $temp_array['service_provide_location_id'] = $a->service_provide_location_id;
            $temp_array['locality'] = $a->locality;
            $temp_array['area_email'] = $a->area_email;
            $temp_array['branch_id'] = $a->branch_id;
            $temp_array['status'] = $a->status;
            array_push($final_areas[$a->govern], $temp_array);
        }

        $this->data['activemenu']     = "master_settings";
        $this->data['actv_submenu'] = 'dlocations';
        $this->data['areas'] = $final_areas;
        $this->data['branches'] = $branches;
        $this->data['css_js_files']  = array('form_validation');
        $this->data['message']         = $this->session->flashdata('message');
        $this->data['pagetitle']     = 'Areas';
        $this->data['content']         = PAGE_SERVICE_PROVIDE_LOCATIONS;
        $this->_render_page(TEMPLATE_ADMIN, $this->data);
    }




    /**
     * Add/Edit delivery location
     *
     * @return boolean
     **/
    function addedit_delivery_location()
    {


        if (isset($_POST['addedit_location'])) {

            $areas = $this->base_model->get_all_areas();

            foreach ($areas as $a) {
                $area_branch_field = 'branch_' . $a->service_provide_location_id;
                $this->form_validation->set_rules($area_branch_field, 'Branch', 'required|xss_clean');
            }
            $this->form_validation->set_error_delimiters('<div class="error">', '</div>');

            if ($this->form_validation->run() == TRUE) {


                foreach ($areas as $a) {
                    $data = array();
                    $area_email_field = 'area_' . $a->service_provide_location_id;
                    $area_branch_field = 'branch_' . $a->service_provide_location_id;
                    $area_status_field = 'status_' . $a->service_provide_location_id;
                    if (isset($_POST[$area_email_field])) {
                        $data['area_email'] = $_POST[$area_email_field];
                    }
                    if (isset($_POST[$area_branch_field]) && $_POST[$area_branch_field] != '') {
                        $data['branch_id'] = $_POST[$area_branch_field];
                    }
                    if (isset($_POST[$area_status_field]) && strlen($_POST[$area_status_field]) > 0) {
                        $data['status'] = $_POST[$area_status_field];
                    }
                  
                    if (!empty($data) && count($data) > 0) {
                        $this->db->where('service_provide_location_id', (int) $a->service_provide_location_id);
                        $this->db->set($data);
                        $this->db->update(TBL_SERVICE_PROVIDE_LOCATIONS);
                    }
                }

                $this->prepare_flashmessage('Updated successfully', 2);
            }
            $areas = $this->base_model->get_all_areas();
            $branches = $this->base_model->get_all_branches();
            $final_areas = array();
            foreach ($areas as $a) {
                if (!array_key_exists($a->govern, $final_areas)) {

                    $final_areas[$a->govern] = array();
                }

                $temp_array = array();
                $temp_array['service_provide_location_id'] = $a->service_provide_location_id;
                $temp_array['locality'] = $a->locality;
                $temp_array['area_email'] = $a->area_email;
                $temp_array['branch_id'] = $a->branch_id;
                $temp_array['status'] = $a->status;
                array_push($final_areas[$a->govern], $temp_array);
            }

            $this->data['activemenu']     = "master_settings";
            $this->data['actv_submenu'] = 'dlocations';
            $this->data['areas'] = $final_areas;
            $this->data['branches'] = $branches;
            $this->data['css_js_files']  = array('form_validation');
            $this->data['message']         = $this->session->flashdata('message');
            $this->data['pagetitle']     = 'Areas';
            $this->data['content']         = PAGE_SERVICE_PROVIDE_LOCATIONS;
            $this->_render_page(TEMPLATE_ADMIN, $this->data);
        } else {
            redirect(URL_DELIVERY_LOCATIONS);
        }
    }
}
