<?php
/**
 *
 * @category  Options
 * 
 * @since     Version 1.0.0
 */
defined('BASEPATH') OR exit('No direct script access allowed');
/**
 * CodeIgniter Options Class
 * 
 * Options CRUD operations.
 *
 * @category  Options
 * 
 */
class Options extends MY_Controller
{

    /**
    | -----------------------------------------------------
    |
    | MODULE:           OPTIONS CONTROLLER
    | -----------------------------------------------------
    | This is Options module controller file.
    | -----------------------------------------------------
     **/
    function __construct()
    {
        parent::__construct();
        check_access('admin');
    }

    /**
     * Fetch options recodrs
     *
     * @return array
     **/ 
    function index()
    {
        if ($this->input->post()) {
            /***
            * 
             * Delete Operation - Start 
            ***/
            $param1 = $this->input->post('param1');
            $param2 = $this->input->post('param2');
            
            if (in_array($param1, array('delete', 'delete_selected', 'activate_selected', 'deactivate_selected')) && !empty($param2)) {
                
                $msg='';
                $status=0;
                if ($param1 == "delete") {
                    if ($this->base_model->delete_record_new(TBL_OPTIONS_SETS, array('option_sets_id' => $param2))) {
                        $msg .= get_languageword('record_deleted_successfully');
                        $status = 0;
                    } else {
                        $msg .= get_languageword('record_not_deleted');
                        $status =1;
                    }
                } else if ($param1 == "delete_selected") {
                    $rows_to_be_deleted = explode(',', $param2);
                    if ($this->base_model->delete_record(TBL_OPTIONS_SETS, 'option_sets_id', $rows_to_be_deleted)) {
                        $msg .= get_languageword('selected_records_deleted_successfully');
                        $status = 0;
                    } else {
                        $msg .= get_languageword('record_not_deleted');
                        $status = 1;
                    }
                } else if ($param1 == "activate_selected") {
                    $rows_to_be_activated = explode(',', $param2);
                    if ($this->base_model->changestatus_multiple_recs(TBL_OPTIONS_SETS, array('option_sets_status' => 'Active'), 'option_sets_id', $rows_to_be_activated)) {
                        $msg .= get_languageword('selected_records_activated_successfully');
                        $status = 0;
                    } else {
                        $msg .= get_languageword('record_not_activated');
                    }

                } else if ($param1 == "deactivate_selected") {
                    $rows_to_be_deactivated = explode(',', $param2);
                    if ($this->base_model->changestatus_multiple_recs(TBL_OPTIONS_SETS, array('option_sets_status' => 'Inactive'), 'option_sets_id', $rows_to_be_deactivated)) {
                        $msg .= get_languageword('selected_records_deactivated_successfully');
                        $status = 0;
                    } else {
                        $msg .= get_languageword('record_not_deactivated');
                        $status = 1;
                    }
                }
                $this->prepare_flashmessage($msg, $status);
                redirect(URL_OPTIONS_INDEX);
            }
        }
        
        $this->data['ajaxrequest'] = array(
        'url' => URL_OPTIONS_AJAX_GET_LIST,
        'disablesorting' => '0,3',
        );
        
        $this->data['css_js_files'] = array('data_tables');
        $this->data['activemenu']     = "options";
        $this->data['message']         = $this->session->flashdata('message');
        $this->data['pagetitle']     = get_languageword('view_options');
        $this->data['content']         = PAGE_OPTIONS;
        $this->_render_page(TEMPLATE_ADMIN, $this->data);
    }
    
    /**
     * Fetch options recodrs
     *
     * @return array
     **/ 
    function ajax_get_list()
    {
        if ($this->input->is_ajax_request()) {
            $data = array();
            $no = $_POST['start'];

            $conditions = array();

            $columns = array('tds.option_sets_name','tds.option_sets_status');    
            
            $query     = "SELECT tds.* from ".TBL_PREFIX.TBL_OPTIONS_SETS." tds WHERE option_sets_id != ''";
            
            
            $records = $this->base_model->get_datatables($query, 'customnew', $conditions, $columns, array('option_sets_name'=>'asc'));
            
            if (!empty($records)) {

                foreach ($records as $record) {
                    $no++;
                    $row = array();

                
                    $row[] = '<input type="checkbox" name="check_rows[]" class="check_rows" value="'.$record->option_sets_id.'"> ';
                    
                    $row[] = '<span>'.$record->option_sets_name.'</span>';
                    
                    $checked = '';
                    $class = 'badge danger';
                    if ($record->option_sets_status == 'Active') {
                        $checked = ' checked';
                        $class = 'badge success';    
                    }
                    $row[] = '<span class="'.$class.'">'.$record->option_sets_status.'</span>';
                    
                    $dta ='';
                    $dta .= '<span>';
                    $dta .= form_open(URL_ADDEDIT_OPTION);
                    $dta .= '<input type="hidden" name="option_sets_id" value="'.$record->option_sets_id.'">';
                    $dta .= '<button type="submit" name="edit_option" class="'.CLASS_EDIT_BTN.'"><i class="'.CLASS_ICON_EDIT.'" ></i></button>';
                    $dta .= form_close();
                    $dta .= '</span>';
                    
                    $str = $dta;
                    
                    $str .= '<a data-toggle="modal" data-target="#commonModal" title="'.get_languageword('delete').'" class="'.CLASS_DELETE_BTN.'" onclick="set_fields(\'delete\', \''.$record->option_sets_id.'\');"><i class="'.CLASS_ICON_DELETE.'" ></i> </a>';
                    
                    $row[] = $str;
                    
                    
                    $data[] = $row;
                
                }
            }

            $output = array(
            "draw" => $_POST['draw'],
            "recordsTotal" => $this->base_model->numrows,
            "recordsFiltered" => $this->base_model->numrows,
            "data" => $data,
            );

            echo json_encode($output);
        }
    }
    
    /**
     * Add/Edit Option
     *
     * @return boolean
     **/ 
    function addedit()
    {
        if (isset($_POST['addedit_option'])) {
            
            $msg='';
            $status=0;
            
            $this->form_validation->set_rules('option_sets_name', get_languageword('option_name'), 'trim|required|xss_clean');
            $this->form_validation->set_rules('option_sets_label', 'Option Set Label', 'trim|required|xss_clean');
            $this->form_validation->set_rules('option_sets_status', 'Status', 'trim|required|xss_clean');
            $this->form_validation->set_rules('option_sets_mandatory', 'Mandatory is required', 'trim|required|is_numeric|xss_clean');
            if($_POST['option_sets_mandatory'] == 0 || $_POST['option_sets_mandatory'] == '0') {
                $this->form_validation->set_rules('option_sets_min', 'Min Value is required', 'trim|required|greater_than_equal_to[0]|xss_clean');
                $this->form_validation->set_rules('option_sets_max', 'Max Value is required', 'trim|required|greater_than_equal_to[0]|xss_clean');
            }
          
            
            $this->form_validation->set_error_delimiters('<div class="error">', '</div>');
            
            $option_sets_id = $this->input->post('option_sets_id');
            
            if ($this->form_validation->run() == TRUE) {
                $data = array();
                $data['option_sets_name']  = $this->input->post('option_sets_name');
                $data['option_sets_status']        = $this->input->post('option_sets_status');
                $data['option_sets_label']        = $this->input->post('option_sets_label');
                $data['option_sets_mandatory']        = $this->input->post('option_sets_mandatory');
                $data['option_sets_min']        = ($this->input->post('option_sets_min'))?$this->input->post('option_sets_min'):0;
                $data['option_sets_max']        = ($this->input->post('option_sets_max'))?$this->input->post('option_sets_max'):0;
                
                if ($this->input->post('option_sets_id') > 0) {
                    $where['option_sets_id'] = $this->input->post('option_sets_id');
                    if ($this->base_model->update_operation($data, TBL_OPTIONS_SETS, $where)) {
                        $msg .= get_languageword('details_saved_successfully');
                        $status = 0;
                    } else {
                        $msg .= get_languageword('details_not_saved');
                        $status = 1;
                    }
                } else {
                
                    $option_sets_id = $this->base_model->insert_operation_id($data, TBL_OPTIONS_SETS);
                  
                    if ($option_sets_id) {
                        $msg .= get_languageword('details_saved_successfully');
                        $status = 0;
                    } else {
                        $msg .= get_languageword('details_not_saved');
                        $status = 1;
                    }
                }
                unset($data, $where);
                
                if ($msg != '') {
                    $this->prepare_flashmessage($msg, $status);
                }
                redirect(URL_OPTIONS_INDEX, REFRESH);
            }
        }
        
        $pagetitle = get_languageword('add_option');
        
        if (isset($_POST['edit_option'])) {
            $option_sets_id = $this->input->post('option_sets_id');
            if ($option_sets_id > 0) {
                $pagetitle = get_languageword('edit_option');
                $record = $this->base_model->fetch_records_from(TBL_OPTIONS_SETS, array('option_sets_id' => $option_sets_id));
                if (empty($record)) {
                    $this->prepare_flashmessage(get_languageword('no_details_found'), 2);
                    redirect(URL_OPTIONS_INDEX);                
                }
                $this->data['record'] =    $record[0];
            } else {
                redirect(URL_OPTIONS_INDEX);
            }
        }
        
        $status_options = $this->base_model->status_options();
        $this->data['status_options'] = $status_options[0];
        
        $this->data['css_js_files']  = array('form_validation');
        $this->data['pagetitle']     = $pagetitle;
        $this->data['activemenu']      = "options";
        $this->data['content']          = PAGE_ADDEDIT_OPTION;
        $this->_render_page(TEMPLATE_ADMIN, $this->data);
    }
}