<?php

/**
 *
 * @category  Orders
 * 
 * @since     Version 1.0.0
 */
defined('BASEPATH') or exit('No direct script access allowed');
/**
 * CodeIgniter Orders Class
 * 
 * Orders operations.
 *
 * @category  Orders
 * 
 */
class Orders extends MY_Controller
{
    private $branch_id = null;

    /**
    | -----------------------------------------------------
    |
    | MODULE:           ORDERS CONTROLLER
    | -----------------------------------------------------
    | This is Orders module controller file.
    | -----------------------------------------------------
     **/
    function __construct()
    {
        parent::__construct();

        check_access('adminorbm');
        if ($this->ion_auth->is_branch_manager()) {
            $this->branch_id = $this->ion_auth->get_user_branch();
        }
    }

    /**
     * Fetch Orders Records
     * 
     *
     * @param string $order_type 
     *
     * @return array
     **/
    function index($order_type = '')
    {
        if ($order_type == '') {
            $order_type = 'new';
        }


        $active_submenu = $order_type;



        $this->data['ajaxrequest'] = array(
            'url' => URL_ORDERS_AJAX_GET_LIST,
            'disablesorting' => '0,8',
            'type' => $order_type,
            'branch' => $this->branch_id
        );

        $this->data['css_js_files'] = array('data_tables');
        $this->data['activemenu']     = "orders";
        $this->data['actv_submenu'] = $active_submenu;
        $this->data['message']         = $this->session->flashdata('message');
        $this->data['pagetitle']     = get_languageword('view_orders');
        $this->data['content']         = PAGE_ORDERS;
        if (!$this->branch_id) :

            $this->_render_page(TEMPLATE_ADMIN, $this->data);
        else :

            $this->_render_page(TEMPLATE_BM, $this->data);

        endif;
    }

    function ajax_orders()
    {
        echo json_encode(array('orders' => $this->base_model->get_orders_count()));
    }
    function ajax_orders_bm()
    {

        echo json_encode(array('orders' => $this->base_model->get_orders_count_bm()));
    }
    /**
     * Fetch Orders Records
     *
     * @return array
     **/
    function ajax_get_list()
    {
        if ($this->input->is_ajax_request()) {

            $data = array();
            $no = $_POST['start'];
            $order_type = $this->input->post('type');

            if ($this->branch_id) {

                $query =  "SELECT distinct tds.* from " . TBL_PREFIX . TBL_ORDERS . " tds LEFT JOIN " . TBL_PREFIX . TBL_SERVICE_PROVIDE_LOCATIONS . " a ON tds.city_id = a.service_provide_location_id WHERE tds.status='" . $order_type . "' AND (tds.branch_id = " . $this->branch_id . " OR a.branch_id=" . $this->branch_id . ")";
            } else {
                $query     = "SELECT tds.* from " . TBL_PREFIX . TBL_ORDERS . " tds WHERE tds.status = '" . $order_type . "' ";
            }
            $conditions = array();

            $columns = array('tds.order_id', 'tds.order_date', 'tds.order_time', 'tds.total_cost', 'tds.customer_name', 'tds.phone', 'tds.status');



            $records = $this->base_model->get_datatables($query, 'customnew', $conditions, $columns, array('order_id' => 'desc'));

            $currency_symbol = $this->config->item('site_settings')->currency_symbol;

            if (!empty($records)) {

                foreach ($records as $record) {
                    $no++;
                    $row = array();

                    $row[] = $no;
                    $row[] = '<span>' . $record->order_id . '</span>';
                    $row[] = '<span>' . get_date($record->order_date) . '</span>';
                    $row[] = '<span>' . $record->order_time . '</span>';
                    $row[] = '<span>' . $currency_symbol . " " . returnPrice($record->total_cost) . '</span>';
                    $row[] = '<span>' . $record->customer_name . '</span>';
                    $row[] = '<span>' . $record->phone . '</span>';
                    $row[] = '<span>' . ucfirst($record->order_type) . '</span>';

                    $class = 'badge danger';
                    if ($record->payment_status == 'CAPTURED' || $record->payment_status == 'CASH ON DELIVERY' || $record->payment_status == 'Card on Delivery (Card Machine)' || $record->payment_status == 'benefitPay') {
                        $class = 'badge delivered';
                    } else {
                        $class = 'badge danger';
                    }
                    if ($record->payment_status == 'benefitPay') {
                        $record->payment_status = 'Benefit Pay';
                    }
                        $row[] = '<span class="' . $class . '">' . ucwords(str_replace("_", " ", strtolower($record->payment_status))) . '</span>';
                    



                    $class = 'badge danger';
                    if ($record->status == 'new') {
                        $class = 'badge new-order';
                    } else if ($record->status == 'delivered') {
                        $class = 'badge delivered';
                    } else if ($record->status == 'process') {
                        $class = 'badge process';
                    } else if ($record->status == 'out_to_deliver') {
                        $class = 'badge out_to_deliver';
                    }
                    $row[] = '<span class="' . $class . '">' . ucwords(str_replace("_", " ", $record->status)) . '</span>';




                    $dta = '';
                    $dta .= '<span>';
                    $dta .= form_open(URL_VIEW_ORDER);
                    $dta .= '<input type="hidden" name="order_id" value="' . $record->order_id . '"><input type="hidden" name="order_type" value="' . $record->status . '">';
                    $dta .= '<button type="submit" name="view_order" class="' . CLASS_VIEW_BTN . '"><i class="' . CLASS_ICON_VIEW . '" ></i></button>';
                    $dta .= form_close();
                    $dta .= '</span>';

                    $str = $dta;

                    $row[] = $str;

                    $data[] = $row;
                }
            }

            $output = array(
                "draw" => $_POST['draw'],
                "recordsTotal" => $this->base_model->numrows,
                "recordsFiltered" => $this->base_model->numrows,
                "data" => $data
            );

            echo json_encode($output);
        }
    }


    /**
     * VIEW ORDER
     *
     * @return array
     **/
    function view_order()
    {

        if (isset($_POST['view_order'])) {

            $order_id = $this->input->post('order_id');
            $order_type = $this->input->post('order_type');

            $order = array();
            $order_products = array();
            $order_addons     = array();
            $order_refunds     = array();

            if ($order_id > 0 && $order_type != '') {

                $active_submenu = $order_type;
                $this->data['actv_submenu'] = $active_submenu;

                if ($this->branch_id && !has_order_access($order_id)) {
                    redirect(URL_ORDERS_INDEX . $order_type);
                }
                //order
                $order = $this->base_model->get_query_result("SELECT * FROM " . TBL_PREFIX . TBL_ORDERS . " WHERE order_id=" . $order_id . " ");

                if (!empty($order)) {

                    $order = $order[0];

                    if ($order->order_type == 'takeaway') {
                        $this->data['branch'] = $this->base_model->get_single_branch((int) $order->branch_id);
                    } else if ($order->order_type == 'delivery') {
                        $order = $this->base_model->get_query_result("SELECT o.*,a.locality,a.govern FROM " . TBL_PREFIX . TBL_ORDERS . " o INNER JOIN " . TBL_PREFIX . TBL_SERVICE_PROVIDE_LOCATIONS . " a on o.city_id = a.service_provide_location_id WHERE o.order_id=" . $order_id . " ");
                        $order = $order[0];
                    }

                    if ($order->payment_type == 'online' && isset($order->transaction_id) && $order->transaction_id != null && $order->transaction_id != '' && ($order->payment_status == '' || $order->payment_status == null || $order->payment_status == 'INITIATED' || $order->payment_status == 'UNKNOWN')) {
                        $temp_key = get_tap_active_key();
                        if ($temp_key && strlen($temp_key) > 0) {
                            $api_key = explode('|||', $temp_key);
                            if (isset($api_key[0]) && isset($api_key[1])) {

                                $headers = array(
                                    "authorization: Bearer " . $api_key[0],
                                    "cache-control: no-cache",
                                    "content-type: application/json"
                                );

                                $response = json_decode(create_curl_request(TAP_CHARGE_URL . "/" . $order->transaction_id, '{}', $headers, "GET"));

                                if ($response) {
                                    if (isset($response->status)) {
                                        $data = $where = array();
                                        $data['payment_status'] = $response->status;
                                        $data['payer_name'] = $response->status;
                                    }

                                    $where['order_id'] = $order_id;
                                    if ($order->payment_status != $response->status) {
                                        $order->payment_status = $response->status;
                                        $this->base_model->update_operation($data, TBL_ORDERS, $where);
                                    }
                                }
                            }
                        }
                    }
                    //Order Refunds
                    $order_refunds = $this->base_model->fetch_records_from(TBL_REFUNDS, array('refund_order_id' => $order_id));
                    $total_refund = 0;
                    $products = array();
                    if (!empty($order_refunds)) {
                        foreach ($order_refunds as $or) {
                            $total_refund += (float) $or->refund_amount;
                        }
                    }
                    //order items
                    $order_products = $this->base_model->fetch_records_from(TBL_ORDER_PRODUCTS, array('order_id' => $order_id, 'is_deleted' => 0));

                    if (!empty($order_products)) {
                        //order addons
                        $order_addons = $this->base_model->fetch_records_from(TBL_ORDER_ADDONS, array('order_id' => $order_id));
                    }

                    foreach ($order_products as $op) {
                        $temp_addons = array();
                        $temp_options = array();
                        $key = $op->common_id;
                        $total_addons_cost = 0;
                        foreach ($order_addons as $oadd) {
                            if ($oadd->common_id == $key) {
                                if ($oadd->is_mandatory == 1 || $oadd->is_mandatory == true) {
                                    array_push($temp_options, $oadd);
                                } else {
                                    array_push($temp_addons, $oadd);
                                    $total_addons_cost += $oadd->price;
                                }
                            }
                        }

                        $op->addons = $temp_addons;
                        $op->options = $temp_options;
    
                        $op->total_addons_cost = $total_addons_cost;
                    }
                } else {
                    redirect(URL_ORDERS_INDEX . 'new');
                }
            } else {
                redirect(URL_ORDERS_INDEX . 'new');
            }
        } else {
            redirect(URL_ORDERS_INDEX . 'new');
        }


        $this->data['order']            = $order;
        $this->data['total_refund']            = $total_refund;
        $this->data['order_products']    = $order_products;
        $this->data['order_addons']        = $order_addons;
        $this->data['order_refunds']        = $order_refunds;
        $this->data['css_js_files'] = array('form_validation');
        $this->data['activemenu']     = "orders";
        $this->data['message']         = $this->session->flashdata('message');
        $this->data['pagetitle']     = get_languageword('view_order');
        $this->data['content']         = PAGE_VIEW_ORDER;
        if (!$this->branch_id) :
            $this->_render_page(TEMPLATE_ADMIN, $this->data);
        else :
            $this->_render_page(TEMPLATE_BM, $this->data);
        endif;
    }


    /**
     * DELETE ORDER ITEM 
     *
     * @return boolean
     **/
    function delete_order()
    {
        if (isset($_POST['delete_item'])) {


            $msg = '';
            $status = 0;

            $details = explode("=", $this->input->post('delete_item_id'));

            if (!empty($details)) {
                $order_id     = $details[0];
                $deleted_id = $details[1];
                $type         = $details[2];

                $order_record = $this->base_model->fetch_records_from(TBL_ORDERS, array('order_id' => $order_id));
                $order_record = $order_record[0];

                $redirect_path = URL_ORDERS_INDEX . $order_record->status;

                if ($type == 'product') {
                    //no_of_items
                    $product = $this->base_model->fetch_records_from(TBL_ORDER_PRODUCTS, array('op_id' => $deleted_id));

                    if (!empty($product)) {
                        $product = $product[0];
                        $product_cost = $product->final_cost;

                        $data = array();
                        $data['is_deleted'] = 1;

                        if ($this->base_model->update_operation($data, TBL_ORDER_PRODUCTS, array('op_id' => $deleted_id))) {
                            //order product deleted bit updated
                            //order_cost

                            unset($data);
                            $order_cost = ($order_record->total_cost) - ($product_cost);
                            if ($order_cost <= 0) {
                                $order_cost = 0;
                            } else {
                                $order_cost = $order_cost;
                            }


                            $data = array();
                            $data['no_of_items'] = $order_record->no_of_items - 1;
                            $data['total_cost']     = $order_cost;


                            if ($this->base_model->update_operation($data, TBL_ORDERS, array('order_id' => $order_id))) {
                                //order product deleted
                                //order cost updated
                                //send email to user - 
                                unset($data);
                                $msg .= get_languageword('order_item_deleted_successfully');
                                $status = 0;
                            } else {
                                //order cost not updated
                                unset($data);
                                $msg .= get_languageword('order_item_not_deleted');
                                $status = 1;

                                $data = array();
                                $data['is_deleted'] = 0;
                                $this->base_model->update_operation($data, TBL_ORDER_PRODUCTS, array('op_id' => $deleted_id));
                            }
                            $this->prepare_flashmessage($msg, $status);
                            redirect($redirect_path);
                        } else {
                            $msg .= get_languageword('item_not_deleted');
                            $status = 1;
                            $this->prepare_flashmessage($msg, $status);
                            redirect($redirect_path);
                        }
                    } else {
                        $msg .= get_languageword('item_not_found');
                        $status = 1;
                        $this->prepare_flashmessage($msg, $status);
                        redirect($redirect_path);
                    }
                } else if ($type == 'addon') {

                    $addon = $this->base_model->fetch_records_from(TBL_ORDER_ADDONS, array('oa_id' => $deleted_id));

                    if (!empty($addon)) {

                        $addon = $addon[0];

                        $addon_cost = $addon->final_cost;

                        $data = array();
                        $data['is_deleted'] = 1;
                        if ($this->base_model->update_operation($data, TBL_ORDER_ADDONS, array('oa_id' => $deleted_id))) {
                            //order addon deleted bit updated
                            //order_cost

                            unset($data);
                            $order_cost = ($order_record->total_cost) - ($addon_cost);
                            if ($order_cost <= 0) {
                                $order_cost = 0;
                            } else {
                                $order_cost = $order_cost;
                            }

                            $data = array();
                            $data['total_cost']     = $order_cost;

                            if ($this->base_model->update_operation($data, TBL_ORDERS, array('order_id' => $order_id))) {
                                //order addon deleted
                                //order cost updated
                                //send email to user - 
                                unset($data);
                                $msg .= get_languageword('order_addon_item_deleted_successfully') . '<br>';
                                $status = 0;
                            } else {

                                //order cost not updated
                                unset($data);
                                $msg .= get_languageword('order_addon_item_not_deleted');
                                $status = 1;

                                $data = array();
                                $data['is_deleted'] = 0;
                                $this->base_model->update_operation($data, TBL_ORDER_ADDONS, array('oa_id' => $deleted_id));
                            }
                            $this->prepare_flashmessage($msg, $status);
                            redirect($redirect_path);
                        } else {
                            $msg .= get_languageword('addon_not_deleted');
                            $status = 1;
                            $this->prepare_flashmessage($msg, $status);
                            redirect($redirect_path);
                        }
                    } else {
                        $msg .= get_languageword('addon_not_found');
                        $status = 1;
                        $this->prepare_flashmessage($msg, $status);
                        redirect($redirect_path);
                    }
                } else {
                    redirect($redirect_path);
                }
            } else {
                redirect(URL_ORDERS_INDEX . 'new');
            }
        } else {
            redirect(URL_ORDERS_INDEX . 'new');
        }
    }


    /**
     * UPDATE ORDER
     *
     * @return boolean
     **/
    function update_order()
    {
        if (isset($_POST['update_order_status'])) {


            $msg = '';
            $status = 0;

            $order_id = $this->input->post('order_id');
            $order = $this->base_model->fetch_records_from(TBL_ORDERS, array('order_id' => $order_id));


            if (!empty($order)) {
                $order = $order[0];
                $user = getUserRec($order->user_id);
                $redirect_path = URL_ORDERS_INDEX . $order->status;
                if ($this->branch_id && !has_order_access($order_id)) {
                    redirect($redirect_path);
                }

                $data = array();
                $data['status']    = $this->input->post('order_status');


                $data['last_updated_by']  = $this->ion_auth->get_user_id();
                $data['last_updated']     = date('Y-m-d H:i:s');

                if ($data['status'] == 'delivered' && $order->paid_amount == '' && $order->paid_date == '') {
                    $data['paid_amount']    = $order->total_cost;
                    $data['paid_date']        = date('Y-m-d');
                }


                if ($data['status'] == 'delivered') {

                    $data['delivered_status'] = 'admin';
                    $data['delivered_status_datetime'] = date('Y-m-d H:i:s');
                }


                if ($data['status'] == 'cancelled') {

                    $data['cancelled_status'] = 'admin';
                    $data['cancelled_status_datetime'] = date('Y-m-d H:i:s');
                }

                $where['order_id'] = $order_id;
                if ($this->base_model->update_operation($data, TBL_ORDERS, $where)) {
                    unset($data);
                    $msg .= get_languageword('order_status_updated_successfully');
                    $status = 0;



                    $this->prepare_flashmessage($msg, $status);
                    redirect($redirect_path);
                } else {
                    $msg .= get_languageword('order_status_not_updated');
                    $status = 1;
                    $this->prepare_flashmessage($msg, $status);
                    redirect($redirect_path);
                }
            } else {
                $msg .= get_languageword('order_status_not_updated');
                $status = 1;
            }
            $this->prepare_flashmessage($msg, $status);
            redirect(URL_ORDERS_INDEX . 'new');
        } else {
            redirect(URL_ORDERS_INDEX . 'new');
        }
    }
    function refund()
    {
        if (isset($_POST['refund_submit']) && isset($_POST['charge_id']) && strlen($_POST['charge_id']) > 0) {
            $tap_id = $_POST['charge_id'];
            $order_products = $order_addons = $order_refunds = array();
            $order = $this->base_model->get_query_result("SELECT * FROM " . TBL_PREFIX . TBL_ORDERS . " WHERE `transaction_id`='" . $tap_id . "'");

            if (!empty($order)) {
                $order = $order[0];
                $order_id = $order->order_id;

                $order_products = $this->base_model->fetch_records_from(TBL_ORDER_PRODUCTS, array('order_id' => $order_id, 'is_deleted' => 0));
                if (!empty($order_products)) {
                    //order addons
                    $order_addons = $this->base_model->fetch_records_from(TBL_ORDER_ADDONS, array('order_id' => $order_id));
                }
                //Order Refunds
                $order_refunds = $this->base_model->fetch_records_from(TBL_REFUNDS, array('refund_order_id' => $order_id));
                $total_refund = 0;
                if (!empty($order_refunds)) {
                    foreach ($order_refunds as $or) {
                        $total_refund += (float) $or->refund_amount;
                    }
                }

                $this->form_validation->set_rules('refund_amount', 'Refund Amount', 'required|xss_clean|greater_than_equal_to[0.01]|less_than_equal_to[8]');
                $this->form_validation->set_rules('refund_reason', 'Refund Reason', 'required|xss_clean');
                $this->form_validation->set_rules('confirm_refund', 'Confirm Refund', 'required|xss_clean');


                if ($this->form_validation->run() == TRUE) {

                    $temp_key = get_tap_active_key();
                    if ($temp_key && strlen($temp_key) > 0) {
                        $api_key = explode('|||', $temp_key);
                        if (isset($api_key[0]) && isset($api_key[1])) {
                            $refund_amount = $this->input->post('refund_amount');
                            $refund_reason = $this->input->post('refund_reason');
                            $charge_id = $this->input->post('charge_id');

                            $headers = array(
                                "authorization: Bearer " . $api_key[0],
                                "cache-control: no-cache",
                                "content-type: application/json"
                            );

                            $response = json_decode(create_curl_request(TAP_CHARGE_URL . "/" . $order->transaction_id, '{}', $headers, "GET"));

                            if ($response && $response->status && $response->status == 'CAPTURED') {
                                $refund_object = new stdClass();
                                $refund_currency = $api_key[1];
                                $refund_object->charge_id = $charge_id;
                                $refund_object->amount = $refund_amount;
                                $refund_object->reason = $refund_reason;
                                $refund_object->currency = $refund_currency;
                                $res = json_decode(create_curl_request(TAP_REFUND_URL, json_encode($refund_object), $headers));

                                if ($res && isset($res->id)) {
                                    if (isset($res->status) && ($res->status == 'PENDING' || $res->status == 'IN_PROGRESS')) {
                                        $input_data = array();
                                        $input_data['refund_order_id'] = $order_id;
                                        $input_data['refund_amount'] = $res->amount;
                                        $input_data['refund_tap_id'] = $res->id;
                                        $input_data['refund_users_id'] = $this->ion_auth->get_user_id();

                                        $r_id = $this->base_model->insert_operation_id($input_data, TBL_REFUNDS);
                                        if ($r_id && $r_id > 0) :
                                            $order_refunds = $this->base_model->fetch_records_from(TBL_REFUNDS, array('refund_order_id' => $order_id));
                                            $total_refund = 0;
                                            if (!empty($order_refunds)) {
                                                foreach ($order_refunds as $or) {
                                                    $total_refund += (float) $or->refund_amount;
                                                }
                                            }
                                        endif;
                                        $this->prepare_flashmessage('Refund Initiated Successfully.', 2);
                                    } else {
                                        $this->prepare_flashmessage($res->response->message, 2);
                                    }
                                } else {
                                    $errors = '';

                                    if ($res->errors && is_array($res->errors)) {

                                        foreach ($res->errors as $error) {
                                            if ($error->description)
                                                $errors .= $error->description . "<br/>";
                                        }
                                    }
                                    if (!isset($res)) {
                                        $errors = 'Unknown Error Occured. Try again later.';
                                    }
                                    $this->prepare_flashmessage($errors, 2);
                                }
                            } else {
                                $this->prepare_flashmessage('Unable to Connect to API Services.', 2);
                            }
                        } else {
                            $this->prepare_flashmessage('Unable to Connect to API Services.', 2);
                        }
                    } else {
                        $this->prepare_flashmessage('Unable to Connect to API Services.', 2);
                    }
                }
                $active_submenu = $order->status;
                $this->data['actv_submenu'] = $active_submenu;
                $this->data['order']            = $order;
                $this->data['order_products']    = $order_products;
                $this->data['order_addons']        = $order_addons;
                $this->data['order_refunds']        = $order_refunds;
                $this->data['total_refund']        = $total_refund;

                $this->data['css_js_files'] = array('form_validation');
                $this->data['activemenu']     = "orders";
                $this->data['message']         = $this->session->flashdata('message');
                $this->data['pagetitle']     = get_languageword('view_order');
                $this->data['content']         = PAGE_VIEW_ORDER;
                $this->_render_page(TEMPLATE_ADMIN, $this->data);
            } else {
                $this->prepare_flashmessage('Invalid Operation.', 2);
                redirect(URL_ORDERS_INDEX);
            }
        } else {
            $this->prepare_flashmessage('Invalid Operation.', 2);
            redirect(URL_ORDERS_INDEX);
        }
    }
}
