  <?php

    /**
     *
     * @category  Settings
     * 
     * @since     Version 1.0.0
     */
    defined('BASEPATH') or exit('No direct script access allowed');

    /**
     * CodeIgniter Settings Class
     * 
     * All can perform all Settings operations.
     *
     * @category  Settings
     * 
     */
    class Settings extends MY_Controller
    {

        /**
    | -----------------------------------------------------
    |
    | MODULE:           SETTINGS CONTROLLER
    | -----------------------------------------------------
    | This is Settings module controller file.
    | -----------------------------------------------------
         **/
        function __construct()
        {
            parent::__construct();
            check_access('admin');
        }

        /**
         * Fetch site settings record
         *
         * @return array
         **/
        function index()
        {
            redirect(URL_SITE_SETTINGS);
        }

        /**
         * Fetch site settings record
         *
         * @return array
         **/
        function site_settings()
        {
            if (isset($_POST['site_settings'])) {
                $msg = '';
                $status = 0;
                $this->form_validation->set_rules('site_title', get_languageword('site_title'), 'trim|required|max_length[100]|xss_clean');
                $this->form_validation->set_rules('phone', get_languageword('phone'), 'trim|required|max_length[30]|xss_clean');
                $this->form_validation->set_rules('portal_email', get_languageword('contact_email'), 'trim|required|valid_email|xss_clean');
                $this->form_validation->set_rules('site_country', get_languageword('site_country'), 'trim|required|xss_clean');
                $this->form_validation->set_rules('currency_symbol', get_languageword('currency_symbol'), 'trim|required|xss_clean');
                $this->form_validation->set_rules('min_order', 'Minimum Order', 'trim|is_numeric|xss_clean|greater_than_equal_to[0]');
                $this->form_validation->set_rules('delivery_fees', 'Delivery Fees', 'trim|is_numeric|xss_clean|greater_than_equal_to[0]');
                $this->form_validation->set_rules('estimated_delivery_time', 'Delivery Fees', 'trim|required|is_natural_no_zero|xss_clean');
                $this->form_validation->set_error_delimiters('<div class="error">', '</div>');

                if ($this->form_validation->run() == TRUE) {
                    $data = array();
                    $data['site_title'] = $this->input->post('site_title');
                    $data['phone']         = $this->input->post('phone');
                    $data['portal_email'] = $this->input->post('portal_email');
                    $data['site_language'] = $this->input->post('site_language');
                    $data['site_country'] = $this->input->post('site_country');
					$data['delivery_time']       = $this->input->post('delivery_time');
                    $data['time_zone']       = $this->input->post('time_zone');
					$data['killswitch']       = $this->input->post('killswitch');
					$data['information_bar']       = $this->input->post('information_bar');
                    $data['popup_enable']       = $this->input->post('popup_enable');
                    $data['currency']       = $this->input->post('currency');
                    $data['currency_symbol'] = $this->input->post('currency_symbol');
                    $data['min_order'] = $this->input->post('min_order');
                    $data['delivery_fees'] = $this->input->post('delivery_fees');
                    $data['estimated_delivery_time'] = $this->input->post('estimated_delivery_time');
                    $data['date_format']       = $this->input->post('date_format');
                    $payment_methods = $this->input->post('payment_methods');
                    if (!empty($payment_methods)) {
                        $payment_methods = implode(',', $payment_methods);
                        $data['payment_methods'] = $payment_methods;
                    } else {
                        $data['payment_methods'] = NULL;
                    }
					$delivery_methods = $this->input->post('delivery_methods');
                    if (!empty($delivery_methods)) {
                        $delivery_methods = implode(',', $delivery_methods);
                        $data['delivery_methods'] = $delivery_methods;
                    } else {
                        $data['delivery_methods'] = NULL;
                    }
                    $where = array('id' => 1);
                    if ($this->base_model->update_operation($data, TBL_SITE_SETTINGS, $where)) {
                        unset($data);
                        $msg  .= get_languageword('details_updated_successfully');
                        $status = 0;
                        //Upload Site Logo
                        if (count($_FILES) > 0) {

                            $record = $this->base_model->fetch_records_from(TBL_SITE_SETTINGS);
                            if (!empty($record)) {
                                $record = $record[0];
                            }
                            $data = array();
                            if ($_FILES['site_logo']['name'] != '' && $_FILES['site_logo']['error'] != 4) {
                                $ext = pathinfo($_FILES['site_logo']['name'], PATHINFO_EXTENSION);
                                $file_name = 'site_logo_' . rand(0, 100) . '.' . $ext;
                                $config['upload_path']         = LOGO_IMG_UPLOAD_PATH_URL;
                                $config['allowed_types']     = 'jpg|jpeg|png|svg|JPG|JPEG|PNG';
                                $config['max_size']          = 5120; //5 MB
                                $config['overwrite'] = true;
                                $config['file_name']  = $file_name;
                                $this->load->library('upload', $config);
                                $this->upload->initialize($config);
                                if ($this->upload->do_upload('site_logo')) {

                                    $data['site_logo'] = $file_name;
                                    $this->create_thumbnail($config['upload_path'] . $file_name, LOGO_IMG_UPLOAD_THUMB_PATH_URL . $file_name, 200, 200);
                                    if (!empty($record)) {
                                        if ($record->site_logo != '' && file_exists(LOGO_IMG_UPLOAD_PATH_URL . $record->site_logo)) {
                                            unlink(LOGO_IMG_UPLOAD_PATH_URL . $record->site_logo);
                                            unlink(LOGO_IMG_UPLOAD_THUMB_PATH_URL . $record->site_logo);
                                        }
                                    }
                                } else {
                                    $msg .= '<br>' . strip_tags($this->upload->display_errors());
                                    $status = 1;
                                }
                            }


                            if ($_FILES['second_site_logo']['name'] != '' && $_FILES['second_site_logo']['error'] != 4) {
                                $ext = pathinfo($_FILES['second_site_logo']['name'], PATHINFO_EXTENSION);
                                $file_name = 'second_site_logo_' . rand(0, 100) . '.' . $ext;
                                $config['upload_path']         = LOGO_IMG_UPLOAD_PATH_URL;
                                $config['allowed_types']     = 'jpg|jpeg|png|svg|JPG|JPEG|PNG';
                                $config['overwrite'] = true;
                                $config['file_name']  = $file_name;
                                $this->load->library('upload', $config);
                                $this->upload->initialize($config);
                                if ($this->upload->do_upload('second_site_logo')) {

                                    $data['second_site_logo'] = $file_name;
                                    $this->create_thumbnail($config['upload_path'] . $file_name, LOGO_IMG_UPLOAD_THUMB_PATH_URL . $file_name, 200, 200);
                                    if (!empty($record)) {
                                        if ($record->second_site_logo != '' && file_exists(LOGO_IMG_UPLOAD_PATH_URL . $record->second_site_logo)) {
                                            unlink(LOGO_IMG_UPLOAD_PATH_URL . $record->second_site_logo);
                                            unlink(LOGO_IMG_UPLOAD_THUMB_PATH_URL . $record->second_site_logo);
                                        }
                                    }
                                } else {
                                    $msg .= '<br>' . strip_tags($this->upload->display_errors());
                                    $status = 1;
                                }
                            }


                            if ($_FILES['fevicon']['name'] != '' && $_FILES['fevicon']['error'] != 4) {

                                $ext = pathinfo($_FILES['fevicon']['name'], PATHINFO_EXTENSION);
                                $file_name1 = 'fevicon_' . rand(0, 10) . '.' . $ext;
                                $config['upload_path']         = FEVICON_IMG_UPLOAD_PATH_URL;
                                $config['allowed_types']     = 'ico|jpg|jpeg|png|JPG|JPEG|PNG';
                                $config['overwrite'] = true;
                                $config['file_name']  = $file_name1;
                                $this->load->library('upload', $config);
                                $this->upload->initialize($config);
                                if ($this->upload->do_upload('fevicon')) {
                                    $data['fevicon'] = $file_name1;
                                    if (!empty($record)) {
                                        if ($record->fevicon != '' && file_exists(FEVICON_IMG_UPLOAD_PATH_URL . $record->fevicon)) {
                                            unlink(FEVICON_IMG_UPLOAD_PATH_URL . $record->fevicon);
                                        }
                                    }
                                } else {
                                    $msg .= '<br>' . strip_tags($this->upload->display_errors());
                                    $status = 1;
                                }
                            }
                            //HOME PAGE IMAGE
                            if ($_FILES['home_page_img']['name'] != '' && $_FILES['home_page_img']['error'] != 4) {
                                $ext = pathinfo($_FILES['home_page_img']['name'], PATHINFO_EXTENSION);
                                $file_name = 'home_page_img_' . rand(0, 10) . '.' . $ext;
                                $config['upload_path']         = HOME_PAGE_IMG_UPLOAD_PATH_URL;
                                $config['overwrite'] = true;

                                //
                                $config['allowed_types']     = 'jpg|jpeg|png|JPG|JPEG|PNG';
                                $config['file_name']  = $file_name;
                                $this->load->library('upload', $config);
                                $this->upload->initialize($config);
                                if ($this->upload->do_upload('home_page_img')) {
                                    $data['home_page_img'] = $file_name;
                                    if (!empty($record)) {
                                        if ($record->home_page_img != '' && file_exists(HOME_PAGE_IMG_UPLOAD_PATH_URL . $record->home_page_img)) {
                                            unlink(HOME_PAGE_IMG_UPLOAD_PATH_URL . $record->home_page_img);
                                        }
                                    }
                                } else {
                                    $msg .= '<br>' . strip_tags($this->upload->display_errors());
                                    $status = 1;
                                }
                            }
							 if ($_FILES['popup_image']['name'] != '' && $_FILES['popup_image']['error'] != 4) {
                                $ext = pathinfo($_FILES['popup_image']['name'], PATHINFO_EXTENSION);
                                $file_name = 'popup_img_' . rand(0, 10) . '.' . $ext;
                                $config['upload_path']         = POPUP_IMG_UPLOAD_PATH_URL;
                                $config['overwrite'] = true;

                                //
                                $config['allowed_types']     = 'jpg|jpeg|png|JPG|JPEG|PNG';
                                $config['file_name']  = $file_name;
                                $this->load->library('upload', $config);
                                $this->upload->initialize($config);
                                if ($this->upload->do_upload('popup_image')) {
                                    $data['popup_image'] = $file_name;
                                    if (!empty($record)) {
                                        if ($record->popup_image != '' && file_exists(POPUP_IMG_UPLOAD_PATH_URL . $record->popup_image)) {
                                            unlink(POPUP_IMG_UPLOAD_PATH_URL . $record->popup_image);
                                        }
                                    }
                                } else {
                                    $msg .= '<br>' . strip_tags($this->upload->display_errors());
                                    $status = 1;
                                }
                            }
                            if (!empty($data)) {
                                $this->base_model->update_operation($data, TBL_SITE_SETTINGS, $where);
                            }
                        }
                    } else {
                        $msg   .= get_languageword('details_not_updated');
                        $status = 1;
                    }

                    $this->prepare_flashmessage($msg, $status);
                    redirect(URL_SITE_SETTINGS, REFRESH);
                }
            }

            $record = array();
            $record = $this->base_model->fetch_records_from(TBL_SITE_SETTINGS);
            if (!empty($record)) {
                $record = $record[0];
            }

            //Language Options
            $lang_opts = get_language_opts();
            $this->data['lang_opts']       = $lang_opts;

            //Language Options
            $currency_opts = get_currency_opts();
            $this->data['currency_opts'] = $currency_opts;


            // TIME ZONES
            $time_zone_options = array();
            $time_zones = $this->base_model->fetch_records_from('calendar_timezones');
            if (!empty($time_zones)) {
                foreach ($time_zones as $row) :
                    $time_zone_options[$row->TimeZone] = $row->TimeZone . '(' . $row->UTC_offset . ')';
                endforeach;
            }
            $this->data['time_zone_options'] = $time_zone_options;

            $this->data['record']          = $record;
            $this->data['css_js_files']  = array('form_validation');
            $this->data['pagetitle']     = get_languageword('site_settings');

            $this->data['activemenu']      = "master_settings";
            $this->data['actv_submenu']  = 'site_settings';

            $this->data['content']          = PAGE_SITE_SETTINGS;
            $this->_render_page(TEMPLATE_ADMIN, $this->data);
        }
        public function validate_time($str)
        {
            if (strrchr($str, ":")) {
                list($hh, $mm) = explode(':', $str);
                if (!is_numeric($hh) || !is_numeric($mm)) {
                    return FALSE;
                } elseif ((int) $hh > 24 || (int) $mm > 59) {
                    return FALSE;
                } elseif (mktime((int) $hh, (int) $mm) === FALSE) {
                    return FALSE;
                }
                return TRUE;
            } else {
                return FALSE;
            }
        }
        function operational_hours()
        {
            if (isset($_POST['operational_settings'])) {

                $msg = '';
                $status = 0;

                $this->form_validation->set_rules('monday_from_time', get_languageword('from_time'), 'required|xss_clean|callback_validate_time');
                $this->form_validation->set_rules('monday_to_time', get_languageword('to_time'), 'required|xss_clean|callback_validate_time');

                $this->form_validation->set_rules('tuesday_from_time', get_languageword('from_time'), 'required|xss_clean|callback_validate_time');
                $this->form_validation->set_rules('tuesday_to_time', get_languageword('to_time'), 'required|xss_clean|callback_validate_time');


                $this->form_validation->set_rules('wednesday_from_time', get_languageword('from_time'), 'required|xss_clean|callback_validate_time');
                $this->form_validation->set_rules('wednesday_to_time', get_languageword('to_time'), 'required|xss_clean|callback_validate_time');


                $this->form_validation->set_rules('thursday_from_time', get_languageword('from_time'), 'required|xss_clean|callback_validate_time');
                $this->form_validation->set_rules('thursday_to_time', get_languageword('to_time'), 'required|xss_clean|callback_validate_time');


                $this->form_validation->set_rules('friday_from_time', get_languageword('from_time'), 'required|xss_clean|callback_validate_time');
                $this->form_validation->set_rules('friday_to_time', get_languageword('to_time'), 'required|xss_clean|callback_validate_time');


                $this->form_validation->set_rules('saturday_from_time', get_languageword('from_time'), 'required|xss_clean|callback_validate_time');
                $this->form_validation->set_rules('saturday_to_time', get_languageword('to_time'), 'required|xss_clean|callback_validate_time');


                $this->form_validation->set_rules('sunday_from_time', get_languageword('from_time'), 'required|xss_clean|callback_validate_time');
                $this->form_validation->set_rules('sunday_to_time', get_languageword('to_time'), 'required|xss_clean|callback_validate_time');


                $this->form_validation->set_error_delimiters('<div class="error">', '</div>');

                if ($this->form_validation->run() == TRUE) {

                    $data = array();

                    $data['monday_from_time']       = $this->input->post('monday_from_time');
                    $data['monday_to_time']       = $this->input->post('monday_to_time');
                    $data['monday_close']       = $this->input->post('monday_close');

                    $data['tuesday_from_time']       = $this->input->post('tuesday_from_time');
                    $data['tuesday_to_time']       = $this->input->post('tuesday_to_time');
                    $data['tuesday_close']       = $this->input->post('tuesday_close');

                    $data['wednesday_from_time']       = $this->input->post('wednesday_from_time');
                    $data['wednesday_to_time']       = $this->input->post('wednesday_to_time');
                    $data['wednesday_close']       = $this->input->post('wednesday_close');


                    $data['thursday_from_time']       = $this->input->post('thursday_from_time');
                    $data['thursday_to_time']       = $this->input->post('thursday_to_time');
                    $data['thursday_close']       = $this->input->post('thursday_close');

                    $data['friday_from_time']       = $this->input->post('friday_from_time');
                    $data['friday_to_time']       = $this->input->post('friday_to_time');
                    $data['friday_close']       = $this->input->post('friday_close');


                    $data['saturday_from_time']       = $this->input->post('saturday_from_time');
                    $data['saturday_to_time']       = $this->input->post('saturday_to_time');
                    $data['saturday_close']       = $this->input->post('saturday_close');

                    $data['sunday_from_time']       = $this->input->post('sunday_from_time');
                    $data['sunday_to_time']       = $this->input->post('sunday_to_time');
                    $data['sunday_close']       = $this->input->post('sunday_close');



                    $where = array('id' => 1);
                    if ($this->base_model->update_operation($data, TBL_OPERATIONAL_HOURS, $where)) {
                        unset($data);
                        $msg  .= get_languageword('details_updated_successfully');
                        $status = 0;
                    } else {
                        $msg   .= get_languageword('details_not_updated');
                        $status = 1;
                    }


                    $this->prepare_flashmessage($msg, $status);
                    redirect(URL_SITE_SETTINGS_OPERATIONAL, REFRESH);
                }
            }

            $record = array();
            $record = $this->base_model->fetch_records_from(TBL_OPERATIONAL_HOURS);
            if (!empty($record)) {
                $record = $record[0];
            }



            $this->data['record']          = $record;
            $this->data['css_js_files']  = array('form_validation');
            $this->data['pagetitle']     = 'Operational Hours';

            $this->data['activemenu']      = "master_settings";
            $this->data['actv_submenu']  = 'operational_hours';

            $this->data['content']          = PAGE_OPERATIONAL_HOURS;
            $this->_render_page(TEMPLATE_ADMIN, $this->data);
        }

        function upgrade()
        {
            $response = create_curl_request(TAP_VERSION_URL, "{}", array());
            $decoded = json_decode($response);

            if (isset($decoded->version)) {
                $this->data['record'] = $decoded;
            } else {
                $this->data['record'] = $response;
            }



            $this->data['css_js_files']  = array('form_validation');

            $this->data['pagetitle']     = 'Upgrade Alligator';

            $this->data['activemenu']      = "master_settings";
            $this->data['actv_submenu']  = 'upgrade';

            $this->data['content']          = 'upgrade';
            $this->_render_page(TEMPLATE_ADMIN, $this->data);
        }

        function process_upgrade()
        {
            $message = '';
            $response = json_decode(create_curl_request(TAP_VERSION_URL, array(), array()));

            if ($response->version && $response->url && version_compare(CURRENT_ALLIGATOR_VERSION, $response->version)==-1 && $response->approved && $response->approved=='yes') {
                if (false != @file_get_contents($response->url, 0, null, 0, 1)) {

                    $destination_dir = APPPATH . 'cache/';
                    $extraction_dir = FCPATH;

                    if (!is_dir($destination_dir)) {
                        mkdir($destination_dir, 0755, true);
                    }
                    $local_zip_file = basename(parse_url($response->url, PHP_URL_PATH));

                    if (!copy($response->url, $destination_dir . $local_zip_file)) {

                        $message = 'Upgrade failed. Failed to copy Zip from remote server.';
                    } else {
                        $zip = new ZipArchive();
                        if ($zip->open($destination_dir . $local_zip_file)) {

                            for ($i = 0; $i < $zip->numFiles; $i++) {
                                if ($zip->extractTo($extraction_dir, array($zip->getNameIndex($i)))) {
                                    $message = 'Upgrade successful.';
                                }
                            }
                            $zip->close();
                            unlink($destination_dir . $local_zip_file);
                            $this->load->library('migration');
                            $this->migration->current();
                        } else {
                            $message = 'Upgrade failed. Unable to extract the archive. Please try again later.';
                        }
                    }
                } else {
                    $message = 'Upgrade failed. Failed to copy Zip from remote server.';
                }
            }
            if ($message != '') {
                $this->prepare_flashmessage($message, 2);
            }
            $this->data['record']          = $response;
            $this->data['css_js_files']  = array('form_validation');
            $this->data['pagetitle']     = 'Upgrade Alligator';

            $this->data['activemenu']      = "master_settings";
            $this->data['actv_submenu']  = 'upgrade';

            $this->data['content']          = 'upgrade';
            $this->_render_page(TEMPLATE_ADMIN, $this->data);
        }




        /**
         * EMAIL TEMPLATES
         *
         * @return array
         **/
        function email_templates()
        {
            if (isset($_POST['edit_template'])) {

                $id = $this->input->post('id');

                if ($id > 0) {
                    $template    = $this->base_model->fetch_records_from(TBL_EMAIL_TEMPLATES, array('id' => $id));

                    if (!empty($template)) {
                        $this->data['record']               = $template[0];
                        $this->data['css_js_files']         = array('ckeditor');
                        $this->data['edit_email_template']  = TRUE;
                        $this->data['pagetitle']            = get_languageword('edit_email_template');
                        $this->data['activemenu']           = "master_settings";
                        $this->data['actv_submenu']         = 'email_templates';

                        $this->data['content']              = PAGE_EDIT_EMAIL_TEMPLATE;
                    } else {
                        redirect(URL_EMAIL_TEMPLATES);
                    }
                } else {
                    redirect(URL_EMAIL_TEMPLATES);
                }
            } else if (isset($_POST['update_email_template'])) {
                $msg = '';
                $status = 0;

                $id = $this->input->post('id');

                if ($id > 0) {

                    $this->form_validation->set_rules('subject', get_languageword('subject'), 'required|xss_clean');
                    $this->form_validation->set_rules('email_template', get_languageword('email_template'), 'required|xss_clean');

                    $this->form_validation->set_error_delimiters('<div class="error">', '</div>');

                    if ($this->form_validation->run() == TRUE) {



                        $data = array();
                        $data['subject']         = $this->input->post('subject');
                        $data['email_template'] = $this->input->post('email_template');

                        $where = array('id' => $id);
                        if ($this->base_model->update_operation($data, TBL_EMAIL_TEMPLATES, $where)) {
                            unset($data);
                            $msg  .= get_languageword('details_updated_successfully');
                            $status = 0;
                        } else {
                            $msg   .= get_languageword('details_not_updated');
                            $status = 1;
                        }

                        $this->prepare_flashmessage($msg, $status);
                        redirect(URL_EMAIL_TEMPLATES, REFRESH);
                    }
                } else {
                    redirect(URL_EMAIL_TEMPLATES);
                }
            } else {
                $records = array();
                $records = $this->base_model->fetch_records_from(TBL_EMAIL_TEMPLATES);
                $this->data['records']          = $records;
                $this->data['css_js_files']  = array('data_tables');
                $this->data['pagetitle']     = get_languageword('email_templates');

                $this->data['activemenu']      = "master_settings";
                $this->data['actv_submenu'] = 'email_templates';


                $this->data['content']          = PAGE_EMAIL_TEMPLATES;
            }
            $this->_render_page(TEMPLATE_ADMIN, $this->data);
        }

        /**
         * Social Network Settings
         *
         * @return array
         **/
        function social_networks()
        {
            if (isset($_POST['social_networks'])) {

                $msg = '';
                $status = 0;

                $this->form_validation->set_rules(
                    'facebook',
                    get_languageword('facebook'),
                    'xss_clean'
                );
                $this->form_validation->set_rules(
                    'twitter',
                    get_languageword('twitter'),
                    'xss_clean'
                );

                $this->form_validation->set_rules(
                    'linked_in',
                    get_languageword('linked_in'),
                    'xss_clean'
                );
                $this->form_validation->set_rules(
                    'instagram',
                    get_languageword('instagram'),
                    'xss_clean'
                );
                $this->form_validation->set_rules(
                    'ig_handle',
                    'Instagram Handle',
                    'xss_clean'
                );
                $this->form_validation->set_rules(
                    'tumblr',
                    get_languageword('tumblr'),
                    'xss_clean'
                );

                $this->form_validation->set_error_delimiters('<div class="error">', '</div>');

                if ($this->form_validation->run() == TRUE) {
                    $data = array();
                    $data['facebook']           = $this->input->post('facebook');
                    $data['twitter']            = $this->input->post('twitter');
                    $data['linked_in']          = $this->input->post('linked_in');
                    $data['instagram']          = $this->input->post('instagram');
                    $data['ig_handle']          = $this->input->post('ig_handle');
                    $data['tumblr']             = $this->input->post('tumblr');

                    $where = array('id' => 1);

                    if ($this->base_model->update_operation($data, TBL_SOCIAL_NETWORKS, $where)) {
                        unset($data);
                        $msg  .= get_languageword('details_updated_successfully');
                        $status = 0;
                    } else {
                        $msg   .= get_languageword('details_not_updated');
                        $status = 1;
                    }

                    $this->prepare_flashmessage($msg, $status);
                    redirect(URL_SOCIAL_NETWORKS, REFRESH);
                }
            }

            $record = array();
            $record = $this->base_model->fetch_records_from(TBL_SOCIAL_NETWORKS);
            if (!empty($record)) {
                $record = $record[0];
            }

            $this->data['record']          = $record;
            $this->data['css_js_files']  = array('form_validation');
            $this->data['pagetitle']     = get_languageword('social_networks');
            $this->data['activemenu']      = "master_settings";
            $this->data['actv_submenu']  = 'social_networks';


            $this->data['content']          = PAGE_SOCIAL_NETWORKS;
            $this->_render_page(TEMPLATE_ADMIN, $this->data);
        }



        /**
         * Theme Color and font Settings
         *
         * @return array
         **/
        function theme_settings()
        {
            if (isset($_POST['theme_settings'])) {

                $msg = '';
                $status = 0;

                $this->form_validation->set_rules(
                    'theme_color',
                    get_languageword('theme_color'),
                    'xss_clean'
                );

                $this->form_validation->set_error_delimiters('<div class="error">', '</div>');
                if ($this->form_validation->run() == TRUE) {
                    $data = array();
                    $data['fld_theme_color']           = $this->input->post('theme_color');
					$data['fld_theme_font']           = $this->input->post('theme_font');
                    $where = array('fld_id' => 1);

                    if ($this->base_model->update_operation($data, TBL_THEME_SETTING, $where)) {
                        unset($data);
                        $msg  .= get_languageword('details_updated_successfully');
                        $status = 0;
                    } else {
                        $msg   .= get_languageword('details_not_updated');
                        $status = 1;
                    }

                    $this->prepare_flashmessage($msg, $status);
                    redirect(URL_THEME_SETTING, REFRESH);
                }
            }

            $record = array();
            $record = $this->base_model->fetch_records_from(TBL_THEME_SETTING);
            if (!empty($record)) {
                $record = $record[0];
            }

            $this->data['record']          = $record;
            $this->data['css_js_files']  = array('form_validation', 'colorpicker');
            $this->data['pagetitle']     = get_languageword('theme_settings');
            $this->data['activemenu']      = "master_settings";
            $this->data['actv_submenu']  = 'theme_settings';
            $this->data['content']          = PAGE_THEME_SETTING;
            $this->_render_page(TEMPLATE_ADMIN, $this->data);
        }

        /**
         * Change Language
         * @param  [string] $language [description]
         * @return [boolean]           [description]
         */
        function change_language($language = NULL)
        {

            $check_lang_strings_existence = $this->base_model->fetch_records_from('languagewords', array('phrase_for' => 'web'), $language);


            if (count($check_lang_strings_existence) > 0) {

                $data = array();
                $data['site_language'] = $language;

                $where = array();
                $where['id'] = 1;
                if ($this->base_model->update_operation($data, 'site_settings', $where)) {
                    unset($data, $where);

                    $this->prepare_flashmessage(get_languageword('language_successfully_changed_to') . ' ' . ucwords($language), 0);
                } else {

                    $this->prepare_flashmessage(get_languageword('language_not_changed_to') . ' ' . ucwords($language), 1);
                }

                redirect(URL_ADMIN_INDEX);
            } else {

                $this->prepare_flashmessage(get_languageword('please_update') . ' ' . ucwords($language) . ' ' . get_languageword('language_strings'), 2);
                redirect(URL_LANGUAGE_INDEX);
            }
        }



        /**
         * APP Settings
         *
         * @return page
         **/
        function app_settings()
        {
            $this->data['pagetitle']     = get_languageword('app_settings');
            $this->data['activemenu']      = "master_settings";
            $this->data['actv_submenu']  = 'app_settings';
            $this->data['content']          = PAGE_APP_SETTINGS;
            $this->_render_page(TEMPLATE_ADMIN, $this->data);
        }
    }
