<?php

/**
 *
 * @category  Welcome
 * 
 * @since     Version 1.0.0
 */
defined('BASEPATH') or exit('No direct script access allowed');

/**
 * CodeIgniter Welcome Class
 * 
 * Welcome operations.
 *
 * @category  Welcome
 * 
 */
class Welcome extends MY_Controller
{

    /**
    | -----------------------------------------------------
    |
    | MODULE:           WELCOME CONTROLLER
    | -----------------------------------------------------
    | This is Welcome module controller file.
    | -----------------------------------------------------
     **/
    function __construct()
    {
        parent::__construct();

        if ($this->ion_auth->logged_in()) {
            if ($this->ion_auth->is_admin()) {
                redirect(URL_ADMIN_INDEX);
            } else if ($this->ion_auth->is_kitchen_manager()) {
                redirect(URL_KITCHEN_MANAGER);
            } else if ($this->ion_auth->is_delivery_manager()) {
                redirect(URL_DELIVERY_MANAGER);
            } else if ($this->ion_auth->is_branch_manager()) {

                redirect(URL_BRANCH_MANAGER);
            }
        } else {
            if ($this->ion_auth->is_killswitch()) {
                if ($this->router->fetch_method() !== 'set_killswitch') {
                    redirect(PAGE_KILL_SWITCH, 'refresh');
                    exit;
                }
            }
        }
    }


    /**
     * Home page
     * Fetch latest 8 menus
     *
     * @return array
     **/
    public function index()
    {
        //get latest 8 menus
        //get all active menus
        $m = 0;
        $menus = array();
        $records = $this->base_model->get_query_result("select menu_id,menu_name from " . TBL_PREFIX . TBL_MENU . " where status='Active' order by menu_name ASC");

        if (!empty($records)) {
            foreach ($records as $record) {

                //check items exist under menu 
                $items = array();

                $items = $this->base_model->get_query_result("select * from " . TBL_PREFIX . TBL_ITEMS . " where menu_id=" . $record->menu_id . " and item_cost>0 and status='Active' ");

                if (!empty($items)) {

                    array_push($menus, $record);
                    $m++;
                }
            }
        }

        $this->data['menus']        = $menus;


        $this->data['activemenu']     = "home";
        $this->data['message']         = $this->session->flashdata('message');
        $this->data['pagetitle']     = get_languageword('home');
        $this->data['content']         = PAGE_HOME;
        $this->_render_page('templates/home-template', $this->data);
    }



    /**
     * Home page Items block
     * Fetch 12 items of selected menu
     * AJAX CALL
     *
     * @return array
     **/
    function get_home_menu_items_block()
    {

        if ($this->input->is_ajax_request()) {

            $page = '';

            $menu_id     = $this->input->post('menu_id');

            $offset = 0; //current offset


            $items          = $this->welcome_model->get_home_menu_items($offset, $menu_id);
            $total_items = $this->welcome_model->numrows;


            $offset = $offset + HOME_MENU_ITEMS_PER_PAGE; //next offset
            $page = $this->load->view('home/fc-home-menu-items', array('items' => $items, 'offset' => $offset, 'total_items' => $total_items));

            echo $page;
        }
    }


    /**
     * Contact US
     *
     * @return boolean
     **/
    function contact_us()
    {
        if (isset($_POST['contactus'])) {

            if (DEMO) {
                $this->prepare_flashmessage(get_languageword('CRUD_operations_disabled_in_DEMO_version'), 2);
                redirect(URL_CONTACT_US, REFRESH);
            }

            $msg = '';
            $status = 0;

            //Form Validations
            $this->form_validation->set_rules('name', get_languageword('name'), 'required|xss_clean');
            $this->form_validation->set_rules('email', get_languageword('email'), 'required|valid_email|xss_clean');
            $this->form_validation->set_rules('subject', get_languageword('subject'), 'required|xss_clean');
            $this->form_validation->set_rules('message', get_languageword('message'), 'required|xss_clean');

            $this->form_validation->set_error_delimiters('<div class="error">', '</div>');

            if ($this->form_validation->run() == TRUE) {

                $name        = $this->input->post('name');
                $email       = $this->input->post('email');
                $subject     = $this->input->post('subject');
                $message     = $this->input->post('message');

                $email_template = $this->base_model->fetch_records_from(TBL_EMAIL_TEMPLATES, array('subject' => 'contact_query', 'status' => 'Active'));

                if (!empty($email_template)) {

                    $email_template = $email_template[0];

                    $content         = $email_template->email_template;


                    $logo_img = '<img src="' . get_site_logo() . '" class="img-responsive">';

                    $content         = str_replace("__SITE_LOGO__", $logo_img, $content);

                    $content         = str_replace("__SITE_TITLE__", $this->config->item('site_settings')->site_title, $content);

                    $content         = str_replace("__USER__", $name, $content);

                    $content         = str_replace("__USER_NAME__", $name, $content);

                    $content         = str_replace("__EMAIL__", $email, $content);

                    $content         = str_replace("__SUBJECT__", $subject, $content);

                    $content         = str_replace("__MESSAGE__", $message, $content);

                    $content         = str_replace("__SITE_TITLE__", $this->config->item('site_settings')->site_title, $content);

                    $from     = $email;
                    $to     = $this->config->item('site_settings')->portal_email;
                    $sub = get_languageword('contact_query') . ' - ' . $this->config->item('site_settings')->site_title;

                    if (sendEmail($from, $to, $sub, $content)) {
                        $msg .= get_languageword('your_contact_request_sent_successfully');
                        $status = 0;
                    } else {
                        $msg .= get_languageword('your_contact_request_not_sent_due_to_some_technical_issue_please_contact_us_after_some_time_thankyou');
                        $status = 2;
                    }
                } else {
                    $msg .= get_languageword('your_contact_query_not_sent_due_to_some_technical_issue_please_contact_us_after_sometime_thank_you');
                    $status = 1;
                }

                $this->prepare_flashmessage($msg, $status);
                redirect(URL_CONTACT_US);
            }
        }
        $this->data['css_js_files']  = array('form_validation');
        $this->data['activemenu']     = "contact_us";
        $this->data['message']         = $this->session->flashdata('message');
        $this->data['pagetitle']     = get_languageword('contact_us');
        $this->data['content']         = 'contact_us';
        $this->_render_page(getTemplate(), $this->data);
    }


    /**
     * About US
     *
     * @return boolean
     **/
    function about_us()
    {
        $record = $this->base_model->fetch_records_from(TBL_PAGES, array('slug' => 'about-us', 'status' => 'Active'));
        if (!empty($record)) {
            $record = $record[0];
        }

        $this->data['record']        = $record;
        $this->data['activemenu']     = "about_us";
        $this->data['message']         = $this->session->flashdata('message');
        $this->data['pagetitle']     = get_languageword('about_us');
        $this->data['content']         = 'about_us';


        $this->_render_page(getTemplate(), $this->data);
    }


    /**
     * How It Works
     *
     * @return boolean
     **/
    function how_it_works()
    {
        $record = $this->base_model->fetch_records_from(TBL_PAGES, array('slug' => 'refunds-policy', 'status' => 'Active'));
        if (!empty($record)) {
            $record = $record[0];
        }

        $this->data['record']        = $record;
        $this->data['activemenu']     = "home";
        $this->data['pagetitle']     = get_languageword('how_it_works');
        $this->data['content']         = 'how_it_works';

        $this->_render_page(getTemplate(), $this->data);
    }


    /**
     * Terms Conditions
     *
     * @return boolean
     **/
    function terms_conditions()
    {
        $record = $this->base_model->fetch_records_from(TBL_PAGES, array('slug' => 'terms-conditions', 'status' => 'Active'));
        if (!empty($record)) {
            $record = $record[0];
        }

        $this->data['record']        = $record;
        $this->data['activemenu']     = "home";
        $this->data['pagetitle']     = get_languageword('terms_conditions');
        $this->data['content']         = 'terms_conditions';
        $this->_render_page(getTemplate(), $this->data);
    }


    /**
     * Privacy Policy
     *
     * @return boolean
     **/
    function privacy_policy()
    {
        $record = $this->base_model->fetch_records_from(TBL_PAGES, array('slug' => 'privacy-policy', 'status' => 'Active'));
        if (!empty($record)) {
            $record = $record[0];
        }

        $this->data['record']        = $record;
        $this->data['activemenu']     = "home";
        $this->data['pagetitle']     = get_languageword('privacy_policy');
        $this->data['content']         = 'privacy_policy';
        $this->_render_page(getTemplate(), $this->data);
    }


    /**
     * FAQs Page
     * Get Faqs categories
     *
     * @return array
     **/
    function faqs()
    {
        //faq categories
        $categories = $this->base_model->get_categories_options('Active');

        $this->data['categories']    = $categories;
        $this->data['activemenu']     = "home";
        $this->data['pagetitle']     = get_languageword('faqs');
        $this->data['content']         = 'faqs-page';
        $this->_render_page(getTemplate(), $this->data);
    }


    /**
     * Get FAQs of selected category
     * AJAX CALL
     *
     * @return array
     **/
    function get_faqs_list()
    {

        if ($this->input->is_ajax_request()) {

            $page = '';

            $fc_id = $this->input->post('fc_id');

            $faqs = $this->base_model->fetch_records_from(TBL_FAQS, array('fc_id' => $fc_id, 'status' => 'Active'));

            $page = $this->load->view('faqs-list-block', array('faqs' => $faqs));

            echo $page;
        }
    }


    /**
     * SITE MAP
     *
     * @return page
     **/
    function site_map()
    {
        $this->data['activemenu']     = "home";
        $this->data['pagetitle']     = get_languageword('site_map');
        $this->data['content']         = 'sitemap';
        $this->_render_page(getTemplate(), $this->data);
    }


    /**
     * MENU PAGE
     * FETCH ALL MENUS
     *
     * @return array
     **/
    function fc_menu()
    {

        $search_item = '';
        if ($this->input->post('search_item')) {
            $search_item = $this->input->post('search_item');
        }
        //get all active menus
        $menus = array();
        $records = $this->base_model->get_query_result("select menu_id,menu_name from " . TBL_PREFIX . TBL_MENU . " where status='Active' order by sort_order ASC");

        $items_list = array();
        if (!empty($records)) {
            foreach ($records as $record) {
                //check items exist under menu 
                $items = $this->base_model->fetch_records_from(TBL_ITEMS, array('menu_id' => $record->menu_id, 'item_cost >=' => 0, 'status' => 'Active'), '*', "sort_order asc");

                if (!empty($items)) {
                    $items_list[$record->menu_id] = $this->welcome_model->get_menu_items_list($record->menu_id);
                    array_push($menus, $record);
                }
            }
        }
        $this->data['menus']        = $menus;
        $this->data['items_list']    = $items_list;
        $this->data['search_item']    = $search_item;
        $this->data['activemenu']     = "menu";
        $this->data['pagetitle']     = "MENU";
        $this->data['content']         = 'fc-menu-page';

        $this->_render_page(getTemplate(), $this->data);
    }


    /**
     * MENU PAGE
     * FETCH SELECTED MENU ITEMS
     * AJAX CALL
     *
     * @return array
     **/
    function get_menu_items_block()
    {

        if ($this->input->is_ajax_request()) {

            $page = '';

            $menu_id     = $this->input->post('menu_id');
            $menu_name   = $this->input->post('menu_name');

            $offset = 0; //current offset


            $items          = $this->welcome_model->get_menu_items($offset, $menu_id);
            $total_items = $this->welcome_model->numrows;


            $offset = $offset + MENU_ITEMS_PER_PAGE; //next offset
            $page = $this->load->view('fc-menu-items-block', array('items' => $items, 'menu_id' => $menu_id, 'menu_name' => $menu_name, 'offset' => $offset, 'total_items' => $total_items));

            echo $page;
        }
    }


    /**
     * MENU PAGE
     * FETCH SELECTED MENU MORE ITEMS  - LOAD MORE
     * AJAX CALL
     *
     * @return array
     **/
    function get_menu_more_items_block()
    {

        if ($this->input->is_ajax_request()) {

            $page = '';

            $menu_id     = $this->input->post('menu_id');

            $offset = $this->input->post('offset');

            $items          = $this->welcome_model->get_menu_items($offset, $menu_id);
            $total_items = $this->welcome_model->numrows;



            $page = $this->load->view('fc-menu-more-items-block', array('items' => $items));

            echo $page;
        }
    }



    function get_search_items_block()
    {

        if ($this->input->is_ajax_request()) {

            $page = '';

            $offset = 0; //current offset

            $search_string = $this->input->post('strng');


            $items           = $this->welcome_model->get_search_items($offset, $search_string);
            $total_items   = $this->welcome_model->numrows;

            $offset = $offset + MENU_ITEMS_PER_PAGE; //next offset


            $page = $this->load->view('fc-search-items-block', array('items' => $items, 'offset' => $offset, 'total_items' => $total_items, 'search_string' => $search_string));


            echo $page;
        }
    }


    /**
     * MENU PAGE
     * FETCH SEARCH ITEMS - LOAD MORE
     * AJAX CALL
     *
     * @return array
     **/
    function get_more_search_items()
    {

        if ($this->input->is_ajax_request()) {

            $page = '';

            $search_string = $this->input->post('strng');

            $offset = $this->input->post('offset');


            $items         = $this->welcome_model->get_search_items($offset, $search_string);
            $total_items = $this->welcome_model->numrows;

            $page = $this->load->view('fc-search-more-items-block', array('items' => $items, 'search_string' => $search_string));

            echo $page;
        }
    }



    /**
     * HOME PAGE, MENU PAGE - ITEM POPUP
     * GET ITEM ADDONS OPTIONS
     * return @PAGE CONTENT FOR MODAL
     * Popup content
     *
     * @return array
     **/
    function get_item_addons_options()
    {

        if ($this->input->is_ajax_request()) {
            $page = '';
            $item_id = $this->input->post('item_id');


            if ($item_id > 0) {

                //get item_record
                $record = $this->base_model->get_query_result("select * from " . TBL_PREFIX . TBL_ITEMS . " where item_id=" . $item_id . " and status='Active'");

                if (!empty($record)) {

                    $currency_symbol = $this->config->item('site_settings')->currency_symbol;

                    $record = $record[0];

                    $page .= '<div class="row"> <div class="mt-2 mb-2 clearfix">
                    <div class="col-sm-12 popupimage">
                    <img src="' . get_item_image($record->item_image_name) . '" alt="' . $record->item_name . '" class="img-responsive" title="' . $record->item_name . '">
                    </div>
                    <div class="col-sm-12">
					<a href="javascript:void(0);" onclick="addToCart()" class="btn btn-sm btn-round btn-primary card-btn pull-right">Add to Cart</a>
                      <div class="cart-item-title">' . $record->item_name . '</div>
					  <p class="cart-item-description">' . $record->item_description . '</p>
                      <div class="card-item-price">' . $currency_symbol . ' <span id="hp_final_cost">' . returnPrice($record->item_cost) . '</span>' . '</div>
                    </div>';


                    $page .= '</div>';


                    $page .= '<input type="hidden" id="selected_item_id" value="' . $record->item_id . '">
					<input type="hidden" id="selected_item_price" value="' . $record->item_cost . '">
					<input type="hidden" id="selected_menu_id" value="' . $record->menu_id . '">
                    <input type="hidden" id="itemFrom" value="items"></div>';

                    $options_array = array();

                    $options = $this->welcome_model->getItemOptionsandAddons($record->item_id);

                    foreach ($options as $opt) {
                        if (!array_key_exists($opt->option_sets_label, $options_array)) {
                            $options_array[$opt->option_sets_label] = array();
                        }
                        array_push($options_array[$opt->option_sets_label], $opt);
                    }
                    $options = $options_array;

                    if (!empty($options)) {
                     
                        $page .= '<div class="panel-group" id="accordion">';
                        $i = 0;
                        $k = 0;
                        foreach ($options as $key => $o) :
                            $i++;
                            $k++;
                            $mandatory = true;
                            $margin_bottom = '';
                            $padding_bottom = '';
                            if(count($options)==$k) {
                                $margin_bottom = 'nomarginbottom';
                                $padding_bottom = 'smallpaddingbottom';
                            }
                            if ($o[0]->option_sets_mandatory == 1) {
                                $mandatory = true;
                                $page .= '
                            <div class="panel panel-default">
                                <div class="panel-heading">
                                    <h4 class="panel-title">
                                        <a class="accordion-toggle" data-toggle="collapse" data-parent="#accordion" href="#collapseaopt' . $o[0]->option_sets_id . '">
                                        <div class="category-title">' . $key . '</div>
                                        </a>
                                    </h4>
                                </div>
                                <div id="collapseaopt' . $o[0]->option_sets_id . '" class="panel-collapse collapse in">
                                    <div class="panel-body">
                                   
                                <div class="menu-list '.$margin_bottom.'">
                                <div class="row">
                                ';
                            } else {
                                $mandatory = false;

                                $page .= ' <div class="panel panel-default">
                            <div class="panel-heading">
                                <h4 class="panel-title">
                                    <a class="accordion-toggle" data-toggle="collapse" data-parent="#accordion" href="#collapseadd' .$o[0]->option_sets_id . '">
                                    <div class="category-title">' . $key . '</div>
                                    </a>
                                </h4>
                            </div>
                            <div id="collapseadd' . $o[0]->option_sets_id . '" class="panel-collapse collapse in">
                                <div class="panel-body '.$padding_bottom.'">
                               
                            <div class="menu-list '.$margin_bottom.'">
                            <div class="row addon-min-max-group">';


                                if (isset($o[0]->option_sets_min) && (int)$o[0]->option_sets_min != 0 && isset($o[0]->option_sets_max) && (int)$o[0]->option_sets_max != 0) {
                                    $margin = '5px;';
                                    $margin2 = '20px;';
                                } else {
                                    $margin = '20px;';
                                    $margin2 = null;
                                }

                                if (isset($o[0]->option_sets_min) && (int)$o[0]->option_sets_min != 0) {

                                    $page .= '<div class="padleft10" style="margin-bottom:' . $margin . ' "><strong> Select minimum ' . $o[0]->option_sets_min . '</strong></div>';
                                }
                                if (isset($o[0]->option_sets_max) && (int)$o[0]->option_sets_max != 0) {
                                    $page .= '<div class="padleft10" style="margin-bottom:';
                                    $page .= ($margin2) ? $margin2 : $margin;
                                    $page .= '"><strong> Select maximum ' . $o[0]->option_sets_max . '</strong></div>';
                                }
                            }
                            $i = 0;
                            foreach ($o as $option) {
                                $i++;
                                if ($mandatory == true) {
                                    $checked = '';
                                    $page .= '<div class="form-check">
                      <label class="form-check-label">
                        <input class="form-check-input radioInput" type="radio" name="item_option_id_' . $option->option_sets_id . '" data-val="' . $option->price . '" value="' . $option->item_option_id . '" ' . $checked . ' onclick="update_cost();">';
                                    if ($option->price > 0) :
                                        $page .= ' <span>' . $option->option_label . '</span>';
                                        $page .= '<span>' . $currency_symbol . " " . returnPrice($option->price) . '</span>';
                                    else :
                                        $page .= ' <span style="width:80%; float:none;">' . $option->option_label . '</span>';
                                        '<span style="width:1%;"></span>';
                                    endif;

                                    $page .= '</label></div>';
                                } else {
                                    $page .= '<div class="form-check dm-add-qty">
                                        <label class="form-check-label">
                                        
                                          <input type="checkbox" name="addonqty_' . $option->item_option_id . '" data-min="' . $o[0]->option_sets_min . '" data-group="' . $key . '" data-max="' . $o[0]->option_sets_max . '" id="' . $option->item_option_id . '" class="addoncheckbox form-check-input" value="' . $option->item_option_id . '" data-val="' . $option->price . '" onclick="update_cost(this);">';
                                    if ($option->price > 0) :
                                        $page .= ' <span>' . $option->option_label . '</span>';
                                        $page .= '<span>' . $currency_symbol . " " . returnPrice($option->price) . '</span>';
                                    else :
                                        $page .= ' <span style="width:80%; float:none;">' . $option->option_label . '</span>';
                                        '<span style="width:1%;"></span>';
                                    endif;

                                    $page .= '</label>
                                      </div>';
                                }
                            }
                            $page .= '</div></div> </div></div></div>';
                        endforeach;
                        $page .= ' 
                           </div>';
                    }

                    $page .= ' <div class="row"><div class="col-xs-12  text-center">
					<a href="javascript:void(0);" onclick="addToCart()" class="btn btn-md btn-round btn-primary card-btn  text-center">Add to Cart</a>
                    </div></div>';
                    $page .= '</div>';

                    echo $page;
                } else {
                    echo FALSE; //item record not found
                }
            } else {
                echo FALSE; //item_id not found
            }
        }
    }



    /**
     * MENU PAGE - CART DIV
     * GET ITEM ADDONS OPTIONS
     * return @PAGE CONTENT FOR MODAL
     * Popup content
     *
     * @return array
     **/
    function get_cart_itm_adns_optns()
    {
        if ($this->input->is_ajax_request()) {

            $page = '';
            $item_id = $this->input->post('item_id');
            $row_id = $this->input->post('row_id');

            $record = array();
            $slctd_options = array();
            $slctd_addons = array();
            if ($item_id > 0 && !empty($this->cart->contents())) {
               
                foreach ($this->cart->contents() as $item) {

                    if ($item['rowid'] == $row_id) {
                        array_push($record, $item);
                        break;
                    }
                }

                if (!empty($record)) {

                    $record = $record[0];

                    if ($record['options']) {
                        foreach ($record['options'] as $key => $option) {
                            if (is_array($option)) {
                                foreach ($option as $p) :
                                    array_push($slctd_options, $option['item_option_id']);
                                endforeach;
                            }
                        }
                    }
                    if (isset($record['options']['addons'])) {

                        foreach ($record['options']['addons'] as $adn) {

                            $adn = explode('=', $adn);
                            if (!empty($adn)) {
                                array_push($slctd_addons, $adn[0]);
                            }
                        }
                    }
                    
                    $currency_symbol = $this->config->item('site_settings')->currency_symbol;

                    $item_price = 0;

                    if (isset($record['subtotal'])) {
                        $item_price = $record['subtotal'];
                    } else {

                        $item_price = $record['qty'] * $record['options']['item_cost'];
                    }


                    if (isset($record['options']['extra_costs_total'])) {
                        $item_price += $record['options']['extra_costs_total']*$record['qty'];
                    }
                 
                    $page .= '<div class="row"><div class="mt-2 mb-2 clearfix">
                    <div class="col-sm-6">
                      <div class="cart-item-title">' . $record['name'] . '</div>
                      <div class="card-item-price">' . $currency_symbol . ' <span id="hpp_final_cost">' . returnPrice($item_price) . '</span>' .' <br/><span>Quantity ' . $record['qty'] . '</span>'. '</div>
                    </div>
					<div class="col-sm-6">
					<a href="javascript:void(0);" onclick="updateToCart()" class="btn btn-sm btn-round btn-primary card-btn">Update to Cart</a>
					</div></div>';



                    $page .= '<input type="hidden" id="selected_item_id" value="' . $record['id'] . '">
					
					<input type="hidden" id="selected_item_price" value="' . $record['options']['item_cost'] . '">
					
					<input type="hidden" id="rowid" value="' . $record['rowid'] . '">
					<input type="hidden" id="itemFrom" value="items">
					
					<input type="hidden" id="itm_qty" value="' . $record['qty'] . '">
					
                 </div>';
                    $options_array = array();

                    $options = $this->welcome_model->getItemOptionsandAddons($record['id']);
                 

                    foreach ($options as $opt) {
                        if (!array_key_exists($opt->option_sets_label, $options_array)) {
                            $options_array[$opt->option_sets_label] = array();
                        }
                        array_push($options_array[$opt->option_sets_label], $opt);
                    }
                    $options = $options_array;

                    if (!empty($options)) {
                        $page .= '<div class="panel-group" id="accordion">';
                        $i = 0;
                        $k = 0;
                        foreach ($options as $key => $o) :
                            $i++;
                            $k++;
                            $mandatory = true;
                            $margin_bottom = '';
                            $padding_bottom = '';
                            if(count($options)==$k) {
                                $margin_bottom = 'nomarginbottom';
                                $padding_bottom = 'smallpaddingbottom';
                            }

                            if ($o[0]->option_sets_mandatory == 1) {
                                $mandatory = true;
                                $page .= '
                         <div class="panel panel-default">
                             <div class="panel-heading">
                                 <h4 class="panel-title">
                                     <a class="accordion-toggle" data-toggle="collapse" data-parent="#accordion" href="#collapseaopt' . $o[0]->option_sets_id . '">
                                     <div class="category-title">' . $key . '</div>
                                     </a>
                                 </h4>
                             </div>
                             <div id="collapseaopt' . $o[0]->option_sets_id . '" class="panel-collapse collapse in">
                                 <div class="panel-body">
                                
                             <div class="menu-list '.$margin_bottom.'">
                             <div class="row">
                             ';
                            } else {
                                $mandatory = false;

                                $page .= ' <div class="panel panel-default">
                         <div class="panel-heading">
                             <h4 class="panel-title">
                                 <a class="accordion-toggle" data-toggle="collapse" data-parent="#accordion" href="#collapseadd' . $o[0]->option_sets_id . '">
                                 <div class="category-title">' . $key . '</div>
                                 </a>
                             </h4>
                         </div>
                         <div id="collapseadd' . $o[0]->option_sets_id . '" class="panel-collapse collapse in">
                             <div class="panel-body '.$padding_bottom.'">
                            
                         <div class="menu-list '.$margin_bottom.'">
                         <div class="row addon-min-max-group">';


                                if (isset($o[0]->option_sets_min) && (int)$o[0]->option_sets_min != 0 && isset($o[0]->option_sets_max) && (int)$o[0]->option_sets_max != 0) {
                                    $margin = '5px;';
                                    $margin2 = '20px;';
                                } else {
                                    $margin = '20px;';
                                    $margin2 = null;
                                }

                                if (isset($o[0]->option_sets_min) && (int)$o[0]->option_sets_min != 0) {

                                    $page .= '<div class="padleft10" style="margin-bottom:' . $margin . ' "><strong> Select minimum ' . $o[0]->option_sets_min . '</strong></div>';
                                }
                                if (isset($o[0]->option_sets_max) && (int)$o[0]->option_sets_max != 0) {
                                    $page .= '<div class="padleft10" style="margin-bottom:';
                                    $page .= ($margin2) ? $margin2 : $margin;
                                    $page .= '"><strong> Select maximum ' . $o[0]->option_sets_max . '</strong></div>';
                                }
                            }
                            $i = 0;
                            foreach ($o as $option) {
                                $i++;
                                $checked = '';

                                if ($mandatory == true) {
                                    if (in_array($option->item_option_id, $slctd_options)) {
                                        $checked = 'checked="checked"';
                                    }
                                    $page .= '<div class="form-check">
                   <label class="form-check-label">
                     <input class="form-check-input radioInput" type="radio" name="item_option_id_' . $option->option_sets_id . '" data-val="' . $option->price . '" value="' . $option->item_option_id . '" ' . $checked . ' onclick="cart_update_cost();">';
                                    if ($option->price > 0) :
                                        $page .= ' <span>' . $option->option_label . '</span>';
                                        $page .= '<span>' . $currency_symbol . " " . returnPrice($option->price) . '</span>';
                                    else :
                                        $page .= ' <span style="width:80%; float:none;">' . $option->option_label . '</span>';
                                        '<span style="width:1%;"></span>';
                                    endif;

                                    $page .= '</label></div>';
                                } else {
                                    if (in_array($option->item_option_id, $slctd_addons)) {
                                        $checked = 'checked="checked"';
                                    }
                                    $page .= '<div class="form-check dm-add-qty">
                                     <label class="form-check-label">
                                     
                                       <input '.$checked.' type="checkbox" name="addonqty_' . $option->item_option_id . '" data-min="' . $o[0]->option_sets_min . '" data-group="' . $key . '" data-max="' . $o[0]->option_sets_max . '" id="' . $option->item_option_id . '" class="addoncheckbox form-check-input" value="' . $option->item_option_id . '" data-val="' . $option->price . '" onclick="cart_update_cost(this);">';
                                    if ($option->price > 0) :
                                        $page .= ' <span>' . $option->option_label . '</span>';
                                        $page .= '<span>' . $currency_symbol . " " . returnPrice($option->price) . '</span>';
                                    else :
                                        $page .= ' <span style="width:80%; float:none;">' . $option->option_label . '</span>';
                                        '<span style="width:1%;"></span>';
                                    endif;

                                    $page .= '</label>
                                   </div>';
                                }
                            }
                            $page .= '</div></div> </div></div></div>';
                        endforeach;
                        $page .= ' 
                        </div>';
                    }


                    $page .= '<div class="row"><div class="col-xs-12  text-center">
					<a href="javascript:void(0);" onclick="updateToCart()" class="btn btn-md btn-round btn-primary card-btn">Update to Cart</a>
                    </div></div>';
                    $page .= '</div>';
                    echo $page;
                } else {
                    echo FALSE; //item record not found
                }
            } else {
                echo FALSE; //item_id not found
            }
        }
 
    }



    /**
     * MENU PAGE
     * LOAD CART DIV
     *
     * @return page
     **/
    function load_cart_div()
    {

        if ($this->input->is_ajax_request()) {

            $page = $this->load->view('fc-cart-div');

            echo $page;
        }
    }



    /**
     * CHECK OUT PAGE
     * LOAD CART SUMMARY DIV
     *
     * @return page
     **/
    function load_cart_summary_div($order_type = 'delivery')
    {

        if ($this->input->is_ajax_request()) {


            $delivery_fee = 0;


            $page = $this->load->view('cart-summary-div', array('delivery_fee' => $delivery_fee, 'order_type' => $order_type));

            echo $page;
        }
    }


    /**
     * CHECK OUT PAGE - CART DIV
     * SHOW CUSTOMIZE ITEM POPUP
     * CONTENT FOR MODAL Popup content
     *
     * @return PAGE
     **/
    function get_item_popup()
    {

        if ($this->input->is_ajax_request()) {

            $page = '';
            $item_id = $this->input->post('item_id');

            $record = array();

            if ($item_id > 0 && !empty($this->cart->contents())) {

                foreach ($this->cart->contents() as $item) {

                    if ($item['id'] == $item_id) {
                        array_push($record, $item);
                        break;
                    }
                }


                if (!empty($record)) {

                    $currency_symbol = $this->config->item('site_settings')->currency_symbol;

                    $record = $record[0];


                    $item_price = 0;
                    if (isset($record['options']['item_option_price'])) {

                        $item_price = $record['qty'] * $record['options']['item_option_price'];
                    } else {

                        $item_price = $record['qty'] * $record['options']['item_cost'];
                    }


                    if (isset($record['options']['extra_costs_total'])) {
                        $item_price += $record['options']['extra_costs_total'];
                    }


                    //$record['subtotal'];


                    //get options
                    $options = $this->welcome_model->getItemOptions($item_id);


                    $page .= '<div class="row">
                    <div class="col-xs-12 col-sm-6">
                      <div class="cart-item-title">' . $record['name'] . '</div>
                    </div>
					
					<div class="col-xs-6 col-sm-3">
                        <div class="card-item-price">' . $currency_symbol . ' <span>' . returnPrice($item_price) . '</span>' . '</div>
                    </div>
					
					
                 </div> <br>';


                    //get addons
                    $addons = $this->welcome_model->getItemAddons($item_id);

                    if (!empty($addons)) {

                        $page .= '<div class="category-title">Add-ons</div>
								<div class="menu-list">';


                        $slctd_addons = array();
                        if (isset($record['options']['addons'])) {

                            foreach ($record['options']['addons'] as $adn) {

                                $adn = explode('=', $adn);
                                if (!empty($adn)) {
                                    array_push($slctd_addons, $adn[0]);
                                }
                            }
                        }




                        foreach ($addons as $addon) {

                            if (in_array($addon->addon_id, $slctd_addons)) {

                                $page .= '<div class="row offr-name">
						<div class="col-xs-9">
						 <span>' . $addon->addon_name . '</span>
						 </div>
						 <div class="col-xs-3">
						 <span>' . $currency_symbol . " " . returnPrice($addon->price) . '</span>
						 </div>
						</div>';
                            }
                        }



                        $page .= '</div>
								</div>';
                    }



                    if (!empty($options)) {

                        $page .= '<div class="category-title">Options</div>
								<div class="menu-list">';
                        // $o=0;
                        foreach ($options as $option) {
                            // $o++;

                            $checked = '';
                            if ($option->item_option_id == $record['options']['item_option_id'] && $option->option_id == $record['options']['option_id']) {
                                $checked = 'checked="checked"';





                                $page .= '<div class="row offr-name">
						<div class="col-xs-9">
						 <span>' . $option->option_name . '</span>
						 </div>
						 <div class="col-xs-3">
						 <span>' . $currency_symbol . " " . returnPrice($option->price) . '</span>
						 </div>
						</div>';
                            }
                        }


                        $page .= ' </div>
								</div>';
                    }






                    echo $page;
                } else {
                    echo FALSE; //item record not found
                }
            } else {
                echo FALSE; //item_id not found
            }
        }
    }


    /**
     * DOWNLOAD APP
     *
     * @return PAGE
     **/
    function download_app()
    {
        $this->data['activemenu']     = "home";
        $this->data['pagetitle']     = get_languageword('download_app');
        $this->data['content']         = 'download_app';
        $this->_render_page(getTemplate(), $this->data);
    }

    function set_killswitch()
    {
        if ($this->ion_auth->is_killswitch()) {
            $this->data['header_hide']     = "1";
            $this->data['pagetitle']     = get_languageword('Sorry, this website is not accepting orders at this time.');
            $this->data['content']         = 'killswitch';
            $this->_render_page(getTemplate(), $this->data);
        } else {
            redirect(base_url(), 'refresh');
            exit;
        }
    }
}
